<?php

namespace App\Console\Commands;

use App\Repositories\SubscriberRepository;
use Illuminate\Console\Command;

class ExportSubscribersCommand extends Command
{

    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'subscribers:export';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Exporta os últimos cadastrados para o Mailchimp';

    /**
     * @var App\Repositories\SubscriberRepository
     */
    protected $subscribers;

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct(SubscriberRepository $subscribers)
    {
        parent::__construct();

        $this->subscribers = $subscribers;
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        $mailchimp   = app('App\Services\MailChimpService');
        $subscribers = $this->subscribers->latest();

        $subscribers->each(function($subscriber) use($mailchimp) {
            $result = $mailchimp->export($subscriber);

            $this->info(' -> Exportado o contato ' . $subscriber->email);
        });

        $this->line('');
        $this->info('Finalizada rotina de exportação de contatos');
    }
}
