<?php

namespace App\Domains\Coupons\Models;
use EscapeWork\LaravelSteroids\Presentable;
use Illuminate\Support\Facades\Config;

use App\Domains\General\Model;

class Coupon extends Model
{

    const TYPE_PRODUCTS = 1;
    const TYPE_COURSES = 2;
    const TYPE_STORE = 3;
    /**
     * Table
     */
    protected $table = 'coupons';

    /**
     * Fillable fields
     */
    protected $fillable = [
        'code',
        'title',
        'type',
        'value',
        'type_value',
        'client_id',
        'start_at',
        'end_at',
        'limit'
    ];

    /**
     * Appends
     */
    protected $casts = [
        'start_at' => 'date',
        'end_at'   => 'date'
    ];

    use Presentable;

    /**
     * The presenter class
     */
    protected $presenter = 'App\Domains\Coupons\Presenters\CouponsPresenter';

    /**
    * Timestsamps
    */
    public $timestamps = false;

    public function setStartAtAttribute($value)
    {
        return $this->_setDateAttribute('start_at', $value);
    }

    public function getStartAtFormatedAttribute()
    {
        return $this->present()->start_at('d/m/Y');
    }

    public function getCodeAttribute()
    {
        if( !isset( $this->attributes['code'] ) ){
            return $this->_generateCode();
        }
        return $this->attributes['code'];
    }

    private function _generateCode(){
        return strtoupper(str_random(5).substr(time(),-5).str_random(5));
    }

    public function setEndAtAttribute($value)
    {
        return $this->_setDateAttribute('end_at', $value);
    }

    public function getEndAtFormatedAttribute()
    {
        return $this->present()->end_at('d/m/Y');
    }

    public static function types()
    {
        $options = [];

        foreach (Config::get('coupons.types') as $group => $data) {
            $options[$group] = $data['title'];
        }

        return $options;
    }

    public static function discountTypes()
    {
        $options = [];

        foreach (Config::get('coupons.discount_types') as $group => $data) {
            $options[$group] = $data['title'];
        }

        return $options;
    }

    public function orders()
    {
        return $this->hasMany('App\Domains\Orders\Models\Order', 'coupon_id');
    }

    public function enrollmentOrders()
    {
        return $this->hasMany('App\Domains\Courses\Models\Order', 'coupon_id');
    }
}
