<?php

namespace App\Domains\Coupons\Notifications;

use Illuminate\Bus\Queueable;
use App\Domains\Courses\Models\Order;
use App\Domains\Coupons\Models\Coupon;
use Illuminate\Notifications\Notification;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;

class NewCouponCoursesNotification extends Notification implements ShouldQueue
{
    use Queueable;

    /**
     * @var App\Domains\Courses\Models\Order
     */
    public $order;

    /**
     * @var App\Domains\Coupons\Models\Coupon
     */
    public $coupon;

    public function __construct(Coupon $coupon, Order $order)
    {
        $this->order = $order;
        $this->coupon = $coupon;
    }

    public function via($notifiable)
    {
        return ['mail'];
    }

    /**
     * Build the mail representation of the notification.
     *
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        $data  = [
            'order' => $this->order,
            'coupon' => $this->coupon
        ];

        return (new MailMessage)
            ->markdown('emails.coupons.new_to_courses', $data)
            ->subject('Cupom de Desconto gerado');
    }

    public function toArray($notifiable)
    {
        return [];
    }
}
