<?php

namespace App\Domains\Coupons\Presenters;
use Illuminate\Support\Facades\Config;

use EscapeWork\LaravelSteroids\Presenter;

class CouponsPresenter extends Presenter
{
    public function start_at($format = 'd/m')
    {
        if( $this->model->start_at ){
            return $this->model->start_at->format($format);
        }

    }

    public function end_at($format = 'd/m')
    {
      if( $this->model->end_at ){
          return $this->model->end_at->format($format);
      }
    }

    public function type()
    {
        return Config::get('coupons.types.' . $this->model->type . '.title');
    }

    public function discountType()
    {
        return Config::get('coupons.discount_types.' . $this->model->type . '.title');
    }

    public function utilized()
    {
        $orders = $this->model->orders()->where("status_id",3)->count();
        $enrollmentOrders = $this->model->enrollmentOrders()->where("status_id",2)->count();

        return $orders + $enrollmentOrders;

    }

    public function hasLimit()
    {
        $orders = $this->model->orders()->where("status_id",3)->count();
        $enrollmentOrders = $this->model->enrollmentOrders()->where("status_id",2)->count();
        $limit = $this->model->limit;

        if( $this->model->client_id){
            $limit = 1;
        }

        if( ($orders + $enrollmentOrders) >= $limit ){
            return false;
        }

        return true;

    }

    public function title()
    {
        if( $this->model->type_value == 0 ){
            return $this->model->code;
        }
        if( $this->model->type_value == 1 ){
            return $this->model->code . " ({$this->model->value}%)";
        }
    }

    public function discount()
    {
        if( $this->model->type_value == 0 ){
            return "R$".number_format($this->model->value, 2, '.','');
        }
        if( $this->model->type_value == 1 ){
            return $this->model->value."%";
        }
    }

    public function couponAfterOrder( $total ){
      if( $this->model->type_value == 0 ){
          if( $this->model->value > $total ){
              $newCouponValue = $this->model->value - $total;
              return "<br>(Saldo do cupom: R$".number_format($newCouponValue, 2, '.','').")";
          }
      }

      if( $this->model->type_value == 1 ){
          $value = ($total * $this->model->value) / 100;
          if( $value > $total ){
              $newCouponValue = $value - $total;
              return "<br>(Saldo do cupom: R$".number_format($newCouponValue, 2, '.','').")";
          }
      }
    }

    public function couponAfterOrderCurrency( $total ){
      if( $this->model->type_value == 0 ){
          if( $this->model->value > $total ){
              $newCouponValue = $this->model->value - $total;
              return $newCouponValue;
          }
          return 0;
      }

      if( $this->model->type_value == 1 ){
          $value = ($total * $this->model->value) / 100;
          if( $value > $total ){
              $newCouponValue = $value - $total;
              return $newCouponValue;
          }
          return 0;
      }
    }

    public function couponDiscountCurrency( $total ){
      if( $this->model->type_value == 0 ){
          if( $this->model->value > $total ){
              $newCouponValue = $this->model->value - $total;
              return number_format($newCouponValue, 2, '.','');
          }
          return number_format($this->model->value, 2, '.','');
      }

      if( $this->model->type_value == 1 ){
          $value = ($total * $this->model->value) / 100;
          if( $value > $total ){
              $newCouponValue = $value - $total;
              return number_format($newCouponValue, 2, '.','');
          }
      }
    }

    public function currency( $total )
    {
        if( $this->model->type_value == 0 ){
            if( $total > $this->model->value ){
                return number_format($this->model->value , 2, '.','');
            }
            return number_format($total, 2, '.','');
        }

        if( $this->model->type_value == 1 ){
            $value = ($total * $this->model->value) / 100;
            $total = $total - $value;
            if( $total <= 0){
              return number_format(0, 2, '.','');
            }

            return number_format($value, 2, '.','');
        }
    }

    public function total( $total ){
      if( $this->model->type_value == 0 ){
          $total = $total - $this->model->value;
          if( $total <= 0){
              return "R$0,00";
          }
          return "R$".number_format($total, 2, ',','.');
      }

      if( $this->model->type_value == 1 ){
          $value = ($total * $this->model->value) / 100;
          $total = $total - $value;
          if( $total <= 0){
              return "R$0,00";
          }
          return "R$".number_format($total, 2, ',','.');
      }
    }

}
