<?php

namespace App\Domains\Coupons\Repositories;

use App\Domains\Coupons\Models\Coupon;
use EscapeWork\LaravelSteroids\Repository;
use Illuminate\Http\Request;

class CouponsRepository extends Repository
{

    public function __construct(Coupon $model)
    {
        $this->setModel($model);
    }

    public function create(Request $request)
    {
        $this->model->fill($request->all());

        $this->model->save();

        return $this->model;
    }

    public function createTouser( $type, $total, $title = null ){
        $coupon = $this->model;
        $coupon->code = $this->_generateCode();
        $coupon->limit = 1;
        $coupon->value = $total;
        $coupon->type = $type;
        $coupon->title = $title;
        $coupon->client_id = auth()->id();
        $coupon->save();

        return $coupon;
    }

    private function _generateCode(){
        return strtoupper(str_random(5).substr(time(),-4).substr(md5(auth()->id()),-3).str_random(3));
    }

    public function update($id, $request)
    {
        $this->model = $this->model->findOrFail($id);
        $this->model->fill($request->all());
        $this->model->save();

        return $this->model;
    }

    public function destroy($id)
    {
        $this->model = $this->model->findOrFail($id);
        $this->model->delete();

        return $this->model;
    }

    public function manager($request)
    {
        if($request->title != '') {
            return $this->model
                ->select('coupons.*')
                ->where('code', 'LIKE', $request->title."%")
                ->orderBy('id', 'desc')
                ->get();
        } else {
            return $this->model
                ->select('coupons.*')
                ->orderBy('id', 'desc')
                ->get();
        }
    }

    public function search($title = '')
    {
        if( $title == ""){
            return null;
        }

        return $this->model
            ->select('coupons.*')
            ->where('code', 'LIKE', $title."%")
            ->orderBy('id', 'desc')
            ->first();
    }

    public function actives()
    {
        return Cache::rememberForever('coupons.actives', function() {
            return $this->model
                        ->active()
                        ->notExpired()
                        ->get();
        });
    }

    public function isValid( $type = null, $code = null )
    {
        $coupon = $this->model->where('code',$code)->first();
        if( !$coupon){
            return false;
        }

        $orders = $coupon->orders()->where("status_id",3)->count();
        $enrollmentOrders = $coupon->enrollmentOrders()->where("status_id",2)->count();

        $utilized = $orders + $enrollmentOrders;
        $limit = $coupon->limit;

        if( $type ){
            if( $coupon->type > 0){
                if( $type != $coupon->type ){
                    return false;
                }
            }
        }

        if( $coupon->client_id ){
            $user_id = auth()->id();
            if( $coupon->client_id !=  $user_id){
                return false;
            }

            if( $utilized >= 1){
                return false;
            }
        }

        if( $coupon->start_at ){
            if( $coupon->start_at > date("Y-m-d") ){
                return false;
            }
        }

        if( $coupon->end_at ){
            if( $coupon->end_at < date("Y-m-d") ){
                return false;
            }
        }

        if( $utilized >= $limit && $limit > 0 ){
            return false;
        }

        return $coupon;

    }

    public function hasLimit( $type = null )
    {
        $orders = $this->model->orders()->where("status_id",3)->count();
        $enrollmentOrders = $this->model->enrollmentOrders()->where("status_id",2)->count();

        $utilized = $orders + $enrollmentOrders;
        $limit = $this->model->limit;

        if( $this->model->client_id ){
            $limit = 1;
        }

        if( $utilized >= $limit ){
            return false;
        }

        return true;

    }


    public function hasStarted()
    {
        if( $this->model->start_at == null || $this->model->start_at <= date("Y-m-d") ){
            return true;
        }

        return false;
    }

    public function hasEnded()
    {
        if( $this->model->end_at == null || $this->model->end_at < date("Y-m-d") ){
            return false;
        }

        return true;
    }

}
