<?php

namespace App\Domains\Data;

use Carbon\Carbon;
use Illuminate\Support\Facades\DB;

trait Datable
{
    public function getData($key, $default = null)
    {
        return $this->data->value($this, $key) !== null ? $this->data->value($this, $key) : $default;
    }

    public function getDataArray($key, $default = [])
    {
        if ($data = $this->getData($key)) {
            return json_decode($data);
        }

        return $default;
    }

    public function saveData($key, $value)
    {
        return $this->data->save($this, $key, $value);
    }

    public function saveDataFromArray($key, $value)
    {
        return $this->saveData($key, json_encode((array) $value));
    }

    public function deleteData($key)
    {
        Data::where('model', '=', get_class($this))
            ->where('model_id', '=', $this->id)
            ->where('key', '=', $key)
            ->delete();
    }

    public function data()
    {
        return $this->morphMany(Data::class, 'data', 'model', 'model_id');
    }

    public function createMultipleData($data)
    {
        $records = [];

        foreach ($data as $key => $value) {
            $records[] = [
                'model'      => get_class($this),
                'model_id'   => $this->id,
                'key'        => $key,
                'value'      => $value,
                'created_at' => Carbon::now(),
                'updated_at' => Carbon::now(),
            ];
        }

        DB::table('data')->insert($records);
    }
}
