<?php

namespace App\Domains\Orders\Delivery;

use Log;
use App\Domains\Orders\Delivery\Models\DeliveryType;
use App\Domains\Orders\Delivery\Models\ClientAddress;
use App\Domains\Orders\Delivery\Models\DeliveryPackage;
//use ELucre\Repositories\OrderRepository;
use Illuminate\Config\Repository as Config;
use Illuminate\Foundation\Application as App;
use App\Domains\Orders\Delivery\Repositories\DeliveryTypeRepository;

class Calculator
{
    /**
     * @var ELucre\Repositories\DeliveryType\DeliveryTypeRepository
     */
    protected $deliveryType;

    public function __construct(
        DeliveryTypeRepository $deliveryType,
        Config $config,
        App $app)
    {
        $this->deliveryType = $deliveryType;
        $this->config = $config;
        $this->app = $app;
    }

    /**
     * Calculando o frete com as formas de entrega disponíveis
     *
     * @param  OrderRepository $order
     * @param  int             $postal_code_destination
     * @return array
     */
    public function calculate($cart, $cepDestino, $product = null)
    {
        if( $product ){
          $measures = $this->getProductsMeasures($product, true);
        }else{
          $measures = $this->getProductsMeasures($cart->products());
        }

        $options  = $this->getOptions($cart, $measures, $cepDestino);

        if (request()->has('debug')) {
            Log::debug('Delivery options');
            Log::debug(print_r($measures, true));
        }

        return $this->formatValues($options, $cart);
    }

    protected function getOptions($cart, $measures, $cepDestino)
    {

        $options = [];
        $types   = $this->deliveryType->getAvailableTypes($measures, $cart->getTotalValue(), $cepDestino, $cart);

        foreach ($types as $type) {
            if ($deliveryOptions = $this->getOption($type, $measures, $cepDestino, $cart)) {

              /*dd( $deliveryOptions );
              if( is_array( $deliveryOptions) && count($deliveryOptions) > 1){
                foreach( $deliveryOptions as $deliveryOption ){

                  if ( isset($deliveryOption['free']) && ! $type->show_when_free) {
                      continue;
                  }

                  $options[] = $deliveryOption;
                }
              }else{*/
                if ($deliveryOptions['free'] && ! $type->show_when_free) {
                    continue;
                }

                $options[] = $deliveryOptions;
              /*}*/

            }
        }

        # removendo o pac caso seja mais caro ou igual ao sedex
        $sedex = null;
        $pac = null;

        foreach( $options as $key => $option){

          if( $option['title'] == 'Sedex'){
            $sedex = ['pos' => $key, 'price' => $option['price'] ];
          }
          if( $option['title'] == 'PAC'){
            $pac = ['pos' => $key, 'price' => $option['price'] ];
          }

        }

        if( $pac && $sedex){
          if( $pac['price'] >= $sedex['price'] ){
            unset( $options[ $pac['pos']]);
          }
        }

        return $options;
    }

    /**
     * Retornando as medidas e peso dos produtos somados
     */
    public function getProductsMeasures($products, $single = false)
    {
        $measures = [
            'freeShipping' => true,
            'weight'       => 0,
            'width'        => 0,
            'height'       => 0,
            'depth'        => 0,
            'volume'       => 0,
            'quantity'     => 0,
            'cubic_volume' => 0
        ];


        if( $single ){
            $weight   = ! is_null($products->weight) ? $products->weight : (float) configuration('peso_padrao');
            $width    = ! is_null($products->width)  ? $products->width  : (float) configuration('largura_padrao');
            $height   = ! is_null($products->height) ? $products->height : (float) configuration('altura_padrao');
            $depth    = ! is_null($products->depth)  ? $products->depth  : (float) configuration('comprimento_padrao');
            $volume   = ceil(($depth * $width * $height) / 6000);
            $multiply = $products->quantity;

            $measures['freeShipping']  = false;
            $measures['weight']       += $weight * $multiply;
            $measures['width']        += $width  * $multiply;
            $measures['height']       += $height * $multiply;
            $measures['depth']        += $depth  * $multiply;
            $measures['volume']       += $volume * $multiply;
            $measures['quantity']     += $products->quantity;
            $measures['cubic_volume'] += ($depth * $width * $height)/10000 * $multiply ;
        }else{
          foreach ($products as $product) {

              $weight   = ! is_null($product->weight) ? $product->weight : (float) configuration('peso_padrao');
              $width    = ! is_null($product->width)  ? $product->width  : (float) configuration('largura_padrao');
              $height   = ! is_null($product->height) ? $product->height : (float) configuration('altura_padrao');
              $depth    = ! is_null($product->depth)  ? $product->depth  : (float) configuration('comprimento_padrao');
              $volume   = ceil(($depth * $width * $height) / 6000);
              $multiply = $product->quantity;

              $measures['freeShipping']  = false;
              $measures['weight']       += $weight * $multiply;
              $measures['width']        += $width  * $multiply;
              $measures['height']       += $height * $multiply;
              $measures['depth']        += $depth  * $multiply;
              $measures['volume']       += $volume * $multiply;
              $measures['quantity']     += $product->quantity;
              $measures['cubic_volume'] += ($depth * $width * $height)/10000 * $multiply ;

          }
        }

        # arredondando valores & calculando a raiz cúbica do volume
        if( $measures['weight'] <= 0.3 ){
            $measures['weight'] = 0.3;
        }else{
          $measures['weight'] = ceil($measures['weight']);
        }


        if ($measures['quantity'] > 1) {
            $measures['width']  = ceil(pow($measures['width'], 1 / 3) * $measures['quantity']);
            $measures['height'] = ceil(pow($measures['height'], 1 / 3) * $measures['quantity']);
            $measures['depth']  = ceil(pow($measures['depth'], 1 / 3) * $measures['quantity']);
            $measures['volume'] = ceil(pow($measures['volume'], 1 / 3));
        }

        $packages = DeliveryPackage::orderBy("weight_cubic","ASC")->get();

        if ($measures['quantity'] > 1 && $packages->count() > 0 && $newMeasures = $this->getProductsMeasuresByPackages($packages, $measures)) {
	        Log::debug($newMeasures);
          return $newMeasures;
        }

        Log::debug($measures);

        return $measures;
    }

    public function getProductsMeasuresByPackages($packages, $measures)
    {
        # verificando se tem algum pacote que se encaixa nas medidas somadas
        if ($package = $packages->byMeasures($measures)) {
            $measures['width']  = $package->width;
            $measures['height'] = $package->height;
            $measures['depth']  = $package->depth;

            return $measures;
        }

        # se nada foi retornado até aqui, o negócio é dividir o peso e tentar colocar em múltiplas caixas
        if ($volume = $packages->divide($measures)) {
            $measures['width']  = $volume;
            $measures['height'] = $volume;
            $measures['depth']  = $volume;

            return $measures;
        }

        return null;
    }

    public function getOption($type, $measures, $cepDestino, $cart = null)
    {
        $data      = [];
        $baseArray = [
            'id'    => $type->id,
            'title' => $type->title,
            'obs'   => $type->obs,
        ];

        switch ($type->delivery_value_type_id) {
            # correios
            case 1:
                $service = $this->app->make($type->valueOption->service);

                if ($option = $service->calculate($type->postal_code_source, $cepDestino, $measures)) {
                    if (isset($option['error']) && $option['error'] === 1) {
                        return false;
                    }

                    $data             = array_merge($baseArray, $option);
                    $data['deadline'] = $data['deadline'] + $type->additional_deadline;
                    $data['free']     = false;

                    # se for frete grátis
                    if ($measures['freeShipping']) {
                        return array_merge(
                            $data,
                            ['price' => null, 'free' => true]
                        );
                    }
                }

                break;

            # valores próprios
            case 2:
                if ($range = $this->deliveryType->getOptionByRange($type, $cepDestino, $measures['weight'])) {
                    $data = array_merge(
                        $baseArray,
                        ['price' => $range->price, 'deadline' => $range->deadline, 'free' => false]
                    );
                }
                break;

            # total Express
            case 5:
              $service = $this->app->make($type->valueOption->service);

              if ($option = $service->calculate($type->postal_code_source, $cepDestino, $measures)) {
                  if (isset($option['error']) && $option['error'] === 1) {
                      return false;
                  }

                  $data             = array_merge($baseArray, $option);
                  $data['deadline'] = $data['deadline'] + $type->additional_deadline;
                  $data['free']     = false;

                  # se for frete grátis
                  if ($measures['freeShipping']) {
                      return array_merge(
                          $data,
                          ['price' => null, 'free' => true]
                      );
                  }
              }

              break;

                case 6:

                $service = $this->app->make($type->valueOption->service);

                  if ($options = $service->getQuote($type->postal_code_source, $cepDestino, $cart->products() )) {
                      foreach( $options as $option){
                        $data[] = $option;
                      }
                  }

              break;

              case 7:

              $service = $this->app->make($type->valueOption->service);

                if ($option = $service->getQuote($type->postal_code_source, $cepDestino, $cart->products() )) {
                      $data[] = $option;
                }

            break;

            default:
                $data = array_merge(
                    $baseArray,
                    ['price' => null, 'deadline' => $type->additional_deadline, 'free' => true]
                );
        }

        # se for grátis, zera o valor
        if ($type->free_shipping) {
            $data['price'] = null;
            $data['free']  = true;
        }
        return $data;
    }

    /**
     * Calculando de um item especifico pelo ID
     */
    public function byId(OrderRepository $order, $delivery_type_id, $postal_code)
    {
        $measures = $this->getProductsMeasures($order->products);
        $type = $this->deliveryType->findOrFail($delivery_type_id);

        return $this->getOption($type, $measures, $postal_code);
    }

    public function formatValues($options, $cart)
    {
        foreach ($options as &$option) {
            $option['price_formated'] = $option['price'] ? number_format($option['price'], 2, ',', '.') : ($cart->isBudget() ? 'A combinar' : 'Grátis');
        }

        return $options;
    }

    public function deliveryOptionsForBudget()
    {
        return DeliveryType::whereIn('id', (array) configuration('budget_delivery_type_id'))->get();
    }
}
