<?php

namespace App\Domains\Orders\Delivery\Correios;

use App\Domains\Orders\Delivery\CalculableType;
use EscapeWork\Frete\Correios\PrecoPrazo;
use EscapeWork\Frete\Correios\Data;
use EscapeWork\Frete\FreteException;

class PAC extends BaseCorreios implements CalculableType
{
    /**
     * @var EscapeWork\Frete\Correios\PrecoPrazo
     */
    protected $correios;

    /**
     * @var array
     */
    protected $measures;

    public function __construct(PrecoPrazo $correios)
    {
        $this->correios = $correios;
    }

    public function calculate($cepOrigem, $cepDestino, $measures)
    {
        $this->measures = $measures;
        $this->measures['weight'] = ceil($measures['weight']);

        if (! $this->validate()) {
            $this->applyMultiplyFactor();
        }

        try {
            $services = array_filter([configuration('correios_codigo_pac_convenio'), Data::PAC]);
            $this->correios->setCodigoServico(implode(',', $services));
            $this->setDefaultAttributes($cepOrigem, $cepDestino);

            return $this->format($this->correios->calculate());
        } catch (FreteException $e) {
            return $this->handleException($e);
        }
    }
}
