<?php

namespace ELucre\Exceptions;

use InvalidArgumentException;
use Illuminate\Support\MessageBag;
use Illuminate\Support\Facades\Response;

class ValidationException extends InvalidArgumentException
{
    /**
     * The validation errors
     * @var array
     */
    protected $validationErrors;

    /**
     * Redirected route
     */
    protected $route;

    public function setValidationErrors($validationErrors)
    {
        if ($validationErrors instanceof MessageBag) {
            $this->validationErrors = $validationErrors;
            return $this;
        }

        $this->validationErrors = new MessageBag;
        $this->validationErrors->add('general', $validationErrors);
        return $this;
    }

    public function getValidationErrors()
    {
        return $this->validationErrors;
    }

    public function setRoute($route)
    {
        $this->route = $route;
        return $this;
    }

    public function getRoute()
    {
        return $this->route;
    }

    public function response()
    {
        if (request()->ajax() || request()->wantsJson()) {
            return Response::json($this->getValidationErrors(), 422);
        }

        if ($route = $this->getRoute()) {
            return redirect()
                ->route($route)
                ->withErrors($this->getValidationErrors())
                ->withInput();
        }

        return redirect()
            ->back()
            ->withErrors($this->getValidationErrors())
            ->withInput();
    }
}
