<?php

namespace App\Domains\Orders\Delivery\Models;

use Cache;
use App\Domains\Orders\Delivery\Collections\DeliveryPackageCollection;
use Illuminate\Database\Eloquent\SoftDeletingTrait;
use App\Domains\General\Model;

class DeliveryPackage extends Model
{

    /**
     * Table
     */
    protected $table = 'delivery_packages';

    /**
     * Fillable
     */
    protected $fillable = [
        'id',
        'title',
        'width',
        'height',
        'depth',
        'weight_cubic',
    ];

    public static function all($columns = ['*'])
    {
        return Cache::remember('delivery.packages.all', 60 * 24 * 7, function() {
            return (new static)->newQuery()->orderBy('weight_cubic')->get();
        });
    }

    public function newCollection(array $models = array())
    {
        return new DeliveryPackageCollection($models);
    }

    public static function boot()
    {
        parent::boot();

        static::saving(function($package) {
            $package->weight_cubic = number_format(($package->width * $package->height * $package->depth) / 6000, 2, '.', '');
        });
    }
}
