<?php

namespace App\Domains\Orders\Delivery\Models;

use App\Domains\General\Model;

class DeliveryType extends Model
{
    /**
     * Table
     */
    protected $table = 'delivery_types';

    /**
     * Fillable
     */
    protected $fillable = [
        'id',
        'delivery_value_type_id',
        'delivery_value_type_option_id',
        'title',
        'description',
        'obs',
        'postal_code_source',
        'price_min',
        'price_max',
        'weight_min',
        'weight_max',
        'free_shipping',
        'additional_deadline',
        'show_when_free',
        'default',
        'active',
        'order',
    ];

    /**
     * Timestamps
     */
    public $timestamps = false;

    /**
     * Dates
     */
    protected $dates = ['deleted_at'];

    /**
     * Ranges
     */
    public function ranges()
    {
        return $this->hasMany('App\Domains\Orders\Delivery\Models\DeliveryTypeRange', 'delivery_type_id');
    }

    /**
    * Restricted Categories
    */
    public function categories()
    {
        return $this->belongsToMany('App\Domains\Products\Models\Category', 'delivery_type_categories');
    }

    public function value()
    {
        return $this->belongsTo('App\Domains\Orders\Delivery\Models\DeliveryValueType', 'delivery_value_type_id');
    }

    public function valueOption()
    {
        return $this->belongsTo('App\Domains\Orders\Delivery\Models\DeliveryValueTypeOption', 'delivery_value_type_option_id');
    }

    public function setPriceMinAttribute($value)
    {
        $this->attributes['price_min'] = $value != '' ? $value : null;
    }

    public function setPriceMaxAttribute($value)
    {
        $this->attributes['price_max'] = $value != '' ? $value : null;
    }

    public function setWeightMinAttribute($value)
    {
        $this->attributes['weight_min'] = $value != '' ? $value : null;
    }

    public function setWeightMaxAttribute($value)
    {
        $this->attributes['weight_max'] = $value != '' ? $value : null;
    }

    public function setAdditionalDeadlineAttribute($value)
    {
        $additional_deadline = (int) $value;

        if ($additional_deadline > 0) {
            $this->attributes['additional_deadline'] = (int) $value;
        } else {
            $this->attributes['additional_deadline'] = null;
        }
    }

    public function setShowWhenFreeAttribute($value)
    {
        $this->attributes['show_when_free'] = $value;
    }

    public function scopeActive($query)
    {
        return $query->where('active', '=', 1);
    }

    public function scopeJoinCategories($query)
    {
        return $query->leftJoin('delivery_type_categories', 'delivery_types.id','=','delivery_type_categories.delivery_type_id') ;
    }

    public static function byTitle()
    {
        return static::where('title', 'A combinar')->first();
    }
}
