<?php

namespace App\Domains\Orders\Delivery\Models;

use App\Domains\General\Model;

class DeliveryTypeRange extends Model
{

    /**
     * Table
     */
    protected $table = 'delivery_type_ranges';

    /**
     * Fillable
     */
    protected $fillable = [
        'id',
        'delivery_type_id',
        'uf',
        'postal_code_initial',
        'postal_code_final',
        'price',
        'deadline',
    ];

    /**
     * Timestamps
     */
    public $timestamps = false;

    /**
     * Validation rules
     */
    public static $validationRules = [
        'deadline' => ['required'],
    ];

    /**
     * Validation messages
     */
    public static $validationMessages = [
        'deadline.required' => 'O prazo é obrigatório',
    ];

    public function scopeJoinStateRanges($query)
    {
        return $query->leftJoin('state_ranges', 'delivery_type_ranges.uf', '=', 'state_ranges.uf');
    }

    public function scopeJoinDeliveryTypes($query)
    {
        return $query->join('delivery_types', 'delivery_types.id', '=', 'delivery_type_ranges.delivery_type_id');
    }

    public function setUfAttribute($value)
    {
        if ($value != '') {
            $this->attributes['uf'] = $value;
        }
    }

    public function setPostalCodeInitialAttribute($value)
    {
        if ($value != '') {
            $this->attributes['postal_code_initial'] = $value;
        }
    }

    public function setPostalCodeFinalAttribute($value)
    {
        if ($value != '') {
            $this->attributes['postal_code_final'] = $value;
        }
    }

    public function setPriceAttribute($value)
    {
        if ($value != '') {
            $this->attributes['price'] = (float) $value;
        }
    }
}
