<?php

namespace App\Domains\Orders\Repositories;

use App\Domains\Orders\Models\Order;
use Carbon\Carbon;
use EscapeWork\LaravelSteroids\Repository;

class OrderRepository extends Repository
{

    public function __construct(Order $model)
    {
        $this->model = $model;
    }

    public function manager($request, $export = false, $type = null)
    {
        $query = $this->model
                    ->with('user')
                    ->select('orders.*')
                    ->joinUsers();

        if ($request->has('status_id') && $request->get('status_id')) {
            if( is_array( $request->get('status_id') )){
              $query->whereIn('orders.status_id', $request->status_id);
            }else{
              $query->where('orders.status_id', '=', $request->status_id);
            }
        }

        if ($request->has('name')) {
            $query->where('users.name', 'like', '%'.$request->name.'%');
        }

        if ($request->has('email')) {
            $query->where('users.email', 'like', '%'.$request->email.'%');
        }

        if ($request->has('start_date') && $request->get('start_date')) {
            $query->where('orders.created_at', '>=', Carbon::createFromFormat('d/m/Y', $request->start_date)->format('Y-m-d') . ' 00:00:00');
        }

        if( $type ){
          $query->where("orders.type",$type);
        }

        if ($request->has('end_date') && $request->get('end_date')) {
            $query->where('orders.created_at', '<=', Carbon::createFromFormat('d/m/Y', $request->end_date)->format('Y-m-d') . ' 25:59:59');
        }

        if ($export) {
            return $query->order($request->order)->get();
        }

        return $query->order($request->order)->paginate();
    }

    public function byStatus( $request ){
        $query = $this->model
                      ->select( \DB::raw('count(*) as totalOrders,  sum(orders.total) valueTotal,  sum(order_delivery.price) totalDelivery, orders.*, status.title'))
                      ->groupBy('status.title')
                      ->pagseguro()
                      ->JoinDelivery()
                      ->joinStatus();

        if ($request->has('status_id') && $request->get('status_id')) {
            if( is_array( $request->get('status_id') )){
              $query->whereIn('orders.status_id', $request->status_id);
            }else{
              $query->where('orders.status_id', '=', $request->status_id);
            }
        }

        if ($request->has('start_date') && $request->get('start_date')) {
            $query->where('orders.created_at', '>=', Carbon::createFromFormat('d/m/Y', $request->start_date)->format('Y-m-d') . ' 00:00:00');
        }

        if ($request->has('end_date') && $request->get('end_date')) {
            $query->where('orders.created_at', '<=', Carbon::createFromFormat('d/m/Y', $request->end_date)->format('Y-m-d') . ' 25:59:59');
        }

        return $query->orderBy("status.id","ASC")->get();
    }

    public function byState($request)
    {
        $query = $this->model
                      ->select( \DB::raw('count(*) as totalOrders, sum(orders.total) valueTotal, orders.*, users.state'))
                      ->groupBy('users.state')
                      ->pagseguro();

        if ($request->has('status_id') && $request->get('status_id')) {
            if( is_array( $request->get('status_id') )){
              $query->whereIn('orders.status_id', $request->status_id);
            }else{
              $query->where('orders.status_id', '=', $request->status_id);
            }
        }

        if ($request->has('start_date') && $request->get('start_date')) {
            $query->where('orders.created_at', '>=', Carbon::createFromFormat('d/m/Y', $request->start_date)->format('Y-m-d') . ' 00:00:00');
        }

        if ($request->has('end_date') && $request->get('end_date')) {
            $query->where('orders.created_at', '<=', Carbon::createFromFormat('d/m/Y', $request->end_date)->format('Y-m-d') . ' 25:59:59');
        }

        return $query->orderBy("totalOrders","DESC")->get();
    }


    public function byCategory($request)
    {
        $query = $this->model
                      ->select( \DB::raw('sum(order_items.quantity) as totalOrders, SUM( order_items.priceTotal) AS totalPrice, orders.*, categories.title, mainCategory.title as mainTitle'))
                      ->groupBy('categories.title')
                      ->joinItems()
                      ->joinProducts()
                      ->joinCategories()
                      ->pagseguro()
                      ->joinMainCategories();

        if ($request->has('status_id') && $request->get('status_id')) {
            if( is_array( $request->get('status_id') )){
              $query->whereIn('orders.status_id', $request->status_id);
            }else{
              $query->where('orders.status_id', '=', $request->status_id);
            }
        }

        if ($request->has('start_date') && $request->get('start_date')) {
            $query->where('orders.created_at', '>=', Carbon::createFromFormat('d/m/Y', $request->start_date)->format('Y-m-d') . ' 00:00:00');
        }

        if ($request->has('end_date') && $request->get('end_date')) {
            $query->where('orders.created_at', '<=', Carbon::createFromFormat('d/m/Y', $request->end_date)->format('Y-m-d') . ' 25:59:59');
        }

        return $query->orderBy("totalOrders","DESC")->get();

    }

    public function byMonths($request)
    {
        $query = $this->model
                    ->select( \DB::raw('count(*) as totalOrders,  sum(orders.total) valueTotal, sum(order_delivery.price) totalDelivery, MONTH(orders.created_at) month, YEAR(orders.created_at) year'))
                    ->groupBy( \DB::raw('month, year') )
                    ->JoinDelivery()
                    ->pagseguro();

        if ($request->has('status_id') && $request->get('status_id')) {
            if( is_array( $request->get('status_id') )){
              $query->whereIn('orders.status_id', $request->status_id);
            }else{
              $query->where('orders.status_id', '=', $request->status_id);
            }
        }

        if ($request->has('start_date') && $request->get('start_date')) {
            $query->where('orders.created_at', '>=', Carbon::createFromFormat('d/m/Y', $request->start_date)->format('Y-m-d') . ' 00:00:00');
        }else{
            $query->where('orders.created_at', '>=', Carbon::now()->addMonths(-11)->format('Y-m-01') . ' 00:00:00');
        }

        if ($request->has('end_date') && $request->get('end_date')) {
            $query->where('orders.created_at', '<=', Carbon::createFromFormat('d/m/Y', $request->end_date)->format('Y-m-d') . ' 25:59:59');
        }else{
            $query->where('orders.created_at', '<=', Carbon::now()->format('Y-m-d') . ' 25:59:59');
        }

        $query->orderByRaw("year DESC, month DESC");

        return $query->orderBy("totalOrders","DESC")->get();

    }

    public function unread()
    {
        return $this->model
                    ->with('user', 'address', 'items')
                    ->finalized()
                    ->unread()
                    ->get();
    }

    public function unreadPagseguro()
    {
        return $this->model
                    ->with('user', 'address', 'items')
                    ->pagseguro()
                    ->unread()
                    ->get();
    }

    public function pendingReview($days = 10)
    {
        $date = Carbon::now()->addDays($days);

        return $this->model
                    ->finalized()
                    ->where('finalized_at', '>=', $date->format('Y-m-d') . ' 00:00:00')
                    ->where('finalized_at', '<=', $date->format('Y-m-d') . ' 23:59:59')
                    ->get();
    }

    public function payments()
    {
        return $this->model

                    ->orderBy('id','DESC')
                    ->get();
    }

    public function findByTransactionCode( $transaction_code){
        $order = $this->model->where('transaction_code',$transaction_code)->first();
        if( !$order){
            return abort('404');
        }

        return $order;

    }

    public function findByCode( $code){
        $order = $this->model->where('code',$code)->first();
        if( !$order){
            return abort('404');
        }

        return $order;

    }
}
