<?php

namespace App\Domains\Orders\Services;

use Illuminate\Http\Request;
use App\Domains\Admin\AdminUser;
use App\Domains\Users\Models\User;
use App\Domains\Orders\Models\Order;
use Illuminate\Support\Facades\Mail;
use App\Domains\Orders\Mailers\OrderCreatedAdminMail;
use App\Domains\Orders\Mailers\OrderUpdatedAdminMail;
use App\Domains\Orders\Notifications\OrderCreatedNotification;

class OrderCreatorService
{
    public function handle(User $user, Request $request, $products)
    {

        //efetuando pagamento via pagseguro
        $data = $request->all();

        $total = $products->reduce(function ($carry, $product) {
            return $carry + ($product->price * $product->quantity);
        });

        $order_id = null;

        if(session()->get('cart.order') !== null) {
            $order_id = session()->get('cart.order');

            $order = Order::find($order_id);

            $order->user_id       = $user->id;
            $order->address_id    = $request->address_id;
            $order->store_id      = $request->store_id;
            $order->delivery_type = $request->delivery_type;
            $order->total         = $total;
            $order->observation   = $request->observation;

            $order->save();

            $order->items()->delete();
        }
        else {
            $order = Order::create([
                'user_id'       => $user->id,
                'address_id'    => $request->address_id,
                'store_id'      => $request->store_id,
                'delivery_type' => $request->delivery_type,
                'total'         => $total,
                'observation'   => $request->observation
            ]);
        }

        foreach ($products as $product) {
            $order->items()->create([
                'product_id' => $product->id,
                'quantity'   => $product->quantity,
                'price'      => $product->price,
            ]);
        }

        $orderDeliveryData = $order->delivery;
        return $order->delivery;

        $order->delivery()->createOrUpdate([
          'type' => strtolower( $data->delivery_option->title ),
          'price' => $data->delivery_option->price,
          'deadline' => $data->delivery_option->deadline,
          'free' => $data->delivery_option->free ? 1 : 0
        ]);

        # removendo os produtos da sessão
        //session()->put('cart.products', []);

        # enviando as notificações pra quem é necessário
        //Mail::to(config('mail.to'))->send(new OrderFinalizedAdminMail($order));
        //$order->user->notify(new OrderFinalizedNotification($order));

        # enviando as notificações pra quem é necessário
        Mail::to(config('mail.to'))->send(new OrderCreatedAdminMail($order));
        $order->user->notify(new OrderCreatedNotification($order));

        return $order;
    }
}
