<?php

namespace App\Domains\Orders\Services;

use Illuminate\Http\Request;
use App\Domains\Admin\AdminUser;
use App\Domains\Users\Models\User;
use App\Domains\Orders\Models\Order;
use Illuminate\Support\Facades\Mail;
use App\Domains\Orders\Mailers\OrderCreatedAdminMail;
use App\Domains\Orders\Mailers\OrderUpdatedAdminMail;
use App\Domains\Orders\Notifications\OrderCreatedNotification;

class OrderFillerService
{
    public function handle(User $user, Request $request, $products)
    {

        //efetuando pagamento via pagseguro
        $data = $request->all();
        $deliveryData = (object) $data['delivery_option'];

        $total = $products->reduce(function ($carry, $product) {
            return $carry + ($product->price * $product->quantity);
        });

        $total += $deliveryData->price;
        $order_id = null;

        if(session()->get('cart.order') !== null) {
            $order_id = session()->get('cart.order');

            $order = Order::find($order_id);

            $order->user_id       = $user->id;
            $order->address_id    = $request->address_id;
            $order->store_id      = $request->store_id;
            $order->delivery_type = $request->delivery_type;
            $order->total         = $total;
            $order->observation   = $request->observation;
            $order->type          = 'payment';
            $order->status        = 4;

            $order->save();

            $order->items()->delete();
        }
        else {
            $order = Order::create([
                'user_id'       => $user->id,
                'address_id'    => $request->address_id,
                'store_id'      => $request->store_id,
                'delivery_type' => $request->delivery_type,
                'total'         => $total,
                'observation'   => $request->observation,
                'status'        => 4,
                'type'          => 'payment'
            ]);
        }

        foreach ($products as $product) {
            $order->items()->create([
                'product_id' => $product->id,
                'quantity'   => $product->quantity,
                'price'      => $product->price,
            ]);
        }

        $order->delivery()->create([
          'type' => strtolower( $deliveryData->title ),
          'price' => $deliveryData->price,
          'deadline' => $deliveryData->deadline,
          'free' => $deliveryData->free ? 1 : 0
        ]);

        $order->createPayment([
            'type'         => 'pagseguro',
            'status'       => 'Aguardando',
            'card_type'    => $request->get('creditCardBrand')['name'],
            'installments' => $request->get('installment')+1,
            'price'        => $total,
            'extra'        => array( "NumPedido" => "", 'plots' => $request->get('plots')[$request->get('installment')] )
        ]);

        # removendo os produtos da sessão
        session()->put('cart.products', []);

        # enviando as notificações pra quem é necessário
        Mail::to(config('mail.to'))->send(new OrderCreatedAdminMail($order));
        $order->user->notify(new OrderCreatedNotification($order));

        return $order;
    }
}
