<?php

namespace App\Domains\Orders\Services;

use Illuminate\Http\Request;
use App\Domains\Admin\AdminUser;
use App\Domains\Users\Models\User;
use App\Domains\Orders\Models\Order;
use Illuminate\Support\Facades\Mail;
use App\Domains\Orders\Mailers\OrderCreatedAdminMail;
use App\Domains\Orders\Mailers\OrderUpdatedAdminMail;
use App\Domains\Orders\Notifications\OrderCreatedNotification;
use App\Domains\Orders\Notifications\OrderPaidNotification;
use App\Domains\Orders\Notifications\OrderCancelledNotification;
use App\Domains\Payment\PagSeguro\CreditCard\Payment;
use App\Domains\Payment\Exceptions\PaymentException;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use App\Domains\Status\Status;
use App\Models\Service;
use Illuminate\Support\Str;
use App\Models\Subscriber;

class OrderPaymentService
{

    /*
    Formata os dados recebidos da view de checkout de acordo com a documentacao do PagSeguro
    */

    public function handle($request)
    {
          $address = (object) $request->get('modal');
          $plan = (object) $request->get('plan');

          $data = (object) $request->all();
          $credit_cart = (object) $data->creditCardBrand;

          $user = User::create([
            'name' => $request->get('name'),
            'company_name' => $request->get('company_name'),
            'cpf' => $request->get('cpf'),
            'cnpj' => $request->get('cnpj'),
            'segment' => $request->get('segment'),
            'contact_name' => $request->get('contact_name'),
            'contact_email' => $request->get('contact_email'),
            'contact_phone' => $request->get('contact_phone'),
            'contact_birthday' => $request->get('contact_birthday'),
            'preference' => $request->get('preference'),
            'email' => $request->get('email'),
            'phone' => $request->get('phone'),
            'postal_code' => $address->postal_code,
            'city' => $address->city,
            'state' => $address->state,
            'district' => $address->district,
            'address' => $address->address,
            'number' => $address->number,
            'address_complement' => $address->complement
          ]);

          /*
          Se o usuario aceitou receber newsletters no mometno do checkout
          */

          if($request->get('newsletter') == 1)
          {
            $subscriber = Subscriber::subscribe($request->all());
          }

          /*
          Salva o endereco paga o envio do PagSeguro.
          Mesmo nao havendo entrega fisica, esses valores sao exigidos na criacao da ordem no PagSeguro
          */

          $address = $user->addresses()->create([
            'title' => 'Endereço',
            'postal_code' => $address->postal_code,
            'city' => $address->city,
            'state' => $address->state,
            'district' => $address->district,
            'address' => $address->address,
            'number' => $address->number,
            'address_complement' => $address->complement
          ]);

          /*
          Salvando as informacoes do pedido no banco de dados
          */

          $order = Order::create([
              'user_id'       => $user->id,
              'address_id'    => $address->id,
              'code'          => Str::random(6) . '-' . Str::random(6). '-' . Str::random(6),
              //'store_id'      => $request->store_id,
              //'delivery_type' => 'withdraw',
              'total'         => $request->get('value'),
              'observation'   => $request->get('observation'),
              'status'        => 1,
              'type'          => $request->get('payment')
          ]);

          /*
          Seleciona as informacoes do plano selecionado e adiciona aos itens do PagSeguro
          */

          $service = app(Service::class)->find($plan->id);

          $order->items()->create([
              'description' => 'Plano ' . $service->title,
              'quantity'   => 1,
              'price'      => $service->value
          ]);

          /*
          Para cada numero selecionado no checkout, adiciona aos itens do Pagseguro
          */

          if($request->has('roc_numbers'))
          {
             $totalRocs = 0;
             $rocs = (object) $request->get('roc_numbers');

             foreach($rocs as $roc)
             {
               $roc = (object) $roc;
               if($roc->quantity > 0)
               {
                 $totalRocs += $roc->quantity;
               }
             }
          }

          /*
          Subtrai do valor do carrinho os DIDs contremplanos gratuitamente no plano
          Caso o numero de DIDs seja igual ou menor ao numero gratuito, cria apenas um item no PagSeguro.
          Caso seja maior, criara 2 itens distintos e com valores distintos tambem
          */

          if($totalRocs <= $service->free_dids)
          {
              $order->items()->create([
                   'description' => 'Números Virtuais Inclusos',
                   'quantity'   => $service->free_dids,
                   'price'      => 0
              ]);
          }else
          {

            $order->items()->create([
                 'description' => 'Números Virtuais Inclusos',
                 'quantity'   => $service->free_dids,
                 'price'      => 0
            ]);

            $order->items()->create([
                 'description' => 'Números Virtuais Adicionais',
                 'quantity'   => $totalRocs - $service->free_dids,
                 'price'      => $service->value_ramal
            ]);

          }


          /*
          Caso hajam numeros 0800 selecionado no checkout, adiciona o item ao Pagseguro
          */

          if($request->has('plan_0800'))
          {
           $plan_0800 = (object) $request->get('plan_0800');

           if($plan_0800->quantity > 0)
           {
             $plan = (object) $plan_0800->plan;
             $order->items()->create([
                 'description' => '0800 - ' . $plan->title,
                 'quantity'   => $plan_0800->quantity,
                 'price'      => $plan->value
             ]);
           }

        }

        /*
        Para cada extra selecionado no checkout, adiciona aos item ao Pagseguro
        */

        if($request->has('extras'))
        {
          foreach($request->get('extras') as $key => $extra)
          {
            $extra = (object) $extra;
            if($extra->quantity > 0)
            {
              $order->items()->create([
                  'description' => $extra->title,
                  'quantity'   => $extra->quantity,
                  'price'      => $extra->value
              ]);
            }
          }

        }

        /*
        Item de forma de entrega, obrigatorio ao criar o pedido no pagseguro
        */

        $order->delivery()->create([
          'type' => 'withdraw',
          'price' => 0,
          'deadline' => 0,
          'free' => 1
        ]);

        return $order;

    }

    /*
    Salva os dados de endereco informados no banco de dados e atribui a ordem criada no checkout
    */

    public function handleOnDelivery( $request){

      $address = (object) $request->get('address');

      $user = User::create([
        'name' => $request->get('name'),
        'email' => $request->get('email'),
        'phone' => $request->get('phone'),
        'postal_code' => $address->postal_code,
        'city' => $address->city,
        'state' => $address->state,
        'district' => $address->district,
        'address' => $address->address,
        'number' => $address->number,
        'address_complement' => $address->address_complement
      ]);

      $address = $user->addresses()->create([
        'title' => 'Endereço',
        'postal_code' => $address->postal_code,
        'city' => $address->city,
        'state' => $address->state,
        'district' => $address->district,
        'address' => $address->address,
        'number' => $address->number,
        'address_complement' => $address->address_complement
      ]);

      $order = Order::create([
          'user_id'       => $user->id,
          'address_id'    => $address->id,
          'total'         => $request->get('value'),
          'observation'   => $request->get('observation'),
          'status'        => 1,
          'type'          => $request->get('payment')
      ]);

      foreach ($request->get("cart") as $key => $product) {
          $order->items()->create([
              'product_id' => $key,
              'quantity'   => $product['quantity'],
              'price'      => $product['value']
          ]);
      }

      $delivery = (object) $request->get('delivery');
      $order->delivery()->create([
        'type' => 'withdraw',
        'price' => $delivery->value,
        'deadline' => 0,
        'free' => 0
      ]);

      $transaction_code = $this->createTransacionCode();
      $order->createPayment([
          'type'         => $request->get('payment'),
          'code'         => $transaction_code,
          'status'       => 'Aguardando Pagamento',
          'price'        => $request->get('value'),
          'installments' => null,
          'card_type'    => null,
          'card_first6'  => null,
          'extra'        => [
              "NumPedido"  => $order->id,
              "plots"  => null
          ]
      ]);

      $order->status_id = Status::WAITING_PAYMENT;
      $order->transaction_code = $transaction_code;
      $order->save();

      DB::commit();

      return $order;

    }

    function createTransacionCode( ){
        return "S" . sprintf( '%04x%04x-%04x-%04x-%04x-%04x%04x%04x',
            mt_rand( 0, 0xffff ), mt_rand( 0, 0xffff ),
            mt_rand( 0, 0xffff ),
            mt_rand( 0, 0x0C2f ) | 0x4000,
            mt_rand( 0, 0x3fff ) | 0x8000,
            mt_rand( 0, 0x2Aff ), mt_rand( 0, 0xffD3 ), mt_rand( 0, 0xff4B )
        );
    }
}
