<?php

namespace App\Domains\Payment\ERede;

use Dalmolin\ERede\Brand;
use Illuminate\Support\Facades\Log;
use Dalmolin\ERede\Resources\Capture;
use App\Domains\Payment\Contracts\Gateway;
use Dalmolin\ERede\Resources\Authorization;
use Dalmolin\ERede\Exceptions\ERedeException;
use App\Domains\Payment\Exceptions\PaymentException;

class CreditCard implements Gateway
{
    public function execute($request, $model)
    {
        try {

            if( $model->discount ){
                $price = $model->total - $model->discount;
            }else{
                $price = $model->total;
            }

            $orderNumber = 'compra-' . $model->id . '-' . time();

            if (app()->environment('local')) {
//                $total = '5090.00'; # aprovado - master
                $total = '5111.00'; # aprovado - visa
//                $total = '5010.01'; # negado
            } else {
                $total = number_format($price, 2, '.', '');
            }

            # criando a autorização no e-rede
            $autorization = new Authorization([
                'Ano'        => substr($request->credit_card_expiration_year, 2, 2),
                'Mes'        => $request->credit_card_expiration_month,
                'Nrcartao'   => $request->credit_card_number,
                'Cvc2'       => $request->credit_card_cvc,
                'Portador'   => $request->credit_card_name,
                'NumPedido'  => $orderNumber,
                'Parcelas'   => $request->installments,
                'Total'      => $total,
            ]);

            $response = $autorization->execute();

            # fazendo a captura no e-rede
            $capture = new Capture([
                'Data'     => $response->Data,
                'NumAutor' => $response->NumAutor,
                'NumSqn'   => $response->NumSqn,
                'Tid'      => $response->Tid,
                'Total'    => $total,
            ]);

            $response2 = $capture->execute();

            # payment response
            $response  = new PaymentResponse($response2);
            $response->setCardType((new Brand($request->credit_card_number))->brand());

            return $response;
        }
        catch (ERedeException $e) {

            Log::error($e);
            throw new PaymentException(trans('messages.e-rede.'.$e->getCode()));
        }
    }
}
