<?php

namespace App\Domains\Payment\Models;

use App\Domains\General\Model;
use App\Domains\Payment\Presenters\PaymentPresenter;
use EscapeWork\LaravelSteroids\Presentable;

class Payment extends Model
{
    use Presentable;

    /**
     * Table
     */
    protected $table = 'payments';

    /**
     * Fillable fields
     */
    protected $fillable = [
        'model',
        'model_id',
        'type',
        'code',
        'status',
        'card_first6',
        'card_type',
        'installments',
        'price',
        'extra',
    ];

    /**
     * Hidden fields
     */
    protected $hidden = [
        'model',
        'model_id',
        'type',
        'created_at',
        'updated_at',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'extra' => 'array',
    ];

    /**
     * Presenter
     */
    protected $presenter = PaymentPresenter::class;

    public function isBoleto()
    {
        return $this->type == 'boleto';
    }

    public function isCreditCard()
    {
        return $this->type == 'credit_card';
    }

    public function setInstallmentsAttribute($installments)
    {
        if ($installments) {
            $this->attributes['installments'] = $installments == '00' ? 1 : (int) $installments;
        }
    }

    public function setCardFirst6Attribute($number)
    {
        if ($number) {
            $this->attributes['card_first6'] = substr($number, 0, 6);
        }
    }
}
