<?php

namespace ELucre\Payment\PagSeguro\Boleto;

use App, Config, Response, Exception;
use Carbon\Carbon;
use ELucre\Models\Order;
use ELucre\Models\PaymentType;
use ELucre\Models\Status;
use ELucre\Payment\PagSeguro\PaymentBase;
use ELucre\Payment\PaymentException;
use ELucre\Payment\PaymentMethod;
use PagSeguro\Configuration\Configure;
use PagSeguro\Domains\Requests\DirectPayment\Boleto;
use PagSeguro\Services\Session;

class Payment extends PaymentMethod
{
    /**
     * PagSeguro Base
     */
    use PaymentBase;

    /**
     * payment_type_id
     *
     * @var int
     */
    public $payment_type_id = PaymentType::PAGSEGURO_BOLETO;

    public function session()
    {
        return Session::create($this->credentials())->getResult();
    }

    public function execute($order, $client, $request)
    {
        $boleto = new Boleto();
        $boleto = $this->addBasePaymentInfos($boleto, $order, $client, $request);

        try {
            $result = $boleto->register($this->credentials());

            # setando códigos e links
            $this->setCode($result->getCode());

            # adicionando o payment link
            $order->finalize([
                'transaction_code' => $result->getCode(),
                'payment_type_id'  => $this->payment_type_id,
                'payment_method'   => 'Boleto',
                'payment_link'     => $result->getPaymentLink(),
            ]);
        } catch (Exception $e) {

            $this->handleException($e, $order, $client, $request);
        }
    }

    public function response()
    {
        return Response::json([
            'code' => $this->getCode()
        ]);
    }
}
