<?php

namespace App\Domains\Payment\PagSeguro\CreditCard;

use App, Config, Response;
use Carbon\Carbon;
use App\Domains\Payment\PagSeguro\Method;
use App\Domains\Payment\PagSeguro\PaymentBase;
use App\Domains\Payment\PaymentException;
use App\Domains\Payment\PaymentMethod;
use Exception;
use PagSeguro\Configuration\Configure;
use PagSeguro\Domains\Requests\DirectPayment\CreditCard;
use PagSeguro\Services\Session;

use App\Domains\Courses\Models\Order as EnrollmentOrder;
use App\Domains\Orders\Models\Order as ProductOrder;

class Payment extends PaymentMethod
{
    /**
     * PagSeguro Base
     */
    use PaymentBase;

    /**
     * payment_type_id
     *
     * @var int
     */
    //public $payment_type_id = PaymentType::PAGSEGURO_CREDIT_CARD;

    /*
    Cria a sessao de identificacao no PagSeguro
    */

    public function session()
    {
        return Session::create($this->credentials())->getResult();

    }

    /*
    Configura o endereco da ordem
    */

    public function mountProductOrder( $creditCard, $order, $client, $request ){

          # endereço de cobrança
          $creditCard->setBilling()->setAddress()->withParameters(
              $order->address->address,
              $order->address->number,
              $order->address->district,
              $order->address->postal_code,
              $order->address->city,
              $order->address->state,
              'BRA',
              $order->address->complement
          );

    }

    /*
    Executa o pagamento no webservice do PagSeguro
    */

    public function execute($order, $client, $request)
    {
        $creditCard = new CreditCard();
        $creditCard = $this->addBasePaymentInfos($creditCard, $order, $client, $request);

        # informações do cartão de crédito
        $creditCard->setMode('DEFAULT');

        if( $request->input('installment_quantity') > 1){
            $creditCard->setInstallment()->withParameters(
                $request->input('installment_quantity'),
                number_format($request->input('installment_value'), 2, '.', ''),
                $request->input('installment_quantity')
            );
        }else{
          $creditCard->setInstallment()->withParameters(
              $request->input('installment_quantity'),
              number_format($request->input('installment_value'), 2, '.', '')
          );
        }

        $creditCard->setHolder()->setName($request->input('credit_card_name'));
        $creditCard->setHolder()->setBirthdate($request->input('credit_card_birth_date'));
        $creditCard->setHolder()->setPhone()->withParameters(
            preg_replace("/[^0-9]/", "", $request->input('credit_card_phone_ddd')),
            preg_replace("/[^0-9]/", "", $request->input('credit_card_phone'))
        );
        $creditCard->setHolder()->setDocument()->withParameters('CPF', $request->input('credit_card_cpf'));
        $creditCard->setToken($request->input('credit_card_token'));

        $this->mountProductOrder( $creditCard, $order, $client, $request );

        try {
            $result = $creditCard->register($this->credentials());

            /*
            Tebnta executar o pagamento com os dados fornecidos no checkout.
            Se finalizado, configura o codigo recebido pelo PagSeguro e salva no banco de dados
            Caso aconteca alguma falha, o checkout exibirá um erro.
            */

            $this->setCode($result->getCode());

            return $result;

        } catch (Exception $exception) {

            dd($exception);

            $this->handleException($exception, $order, $client, $request);
        }
    }

    /*
    Transforma o retorno do PagSeguro no formato correto a ser lido pela aplicacao
    */

    public function response()
    {
        return Response::json([
            'code' => $this->getCode()
        ]);
    }

    public function update(Order $order)
    {
        // do nothing
    }
}
