<?php

namespace App\Domains\Payment\PagSeguro\CreditCard;

use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Input;
use Illuminate\Support\Facades\Response;
use Illuminate\Http\Request;

class PaymentController extends Controller
{

    public function session()
    {

        if (env('TEST_PAGSEGURO') === 'local')
        {
          $payment =  new Payment(
              config('payment.pagseguro.sandbox.email'),
              config('payment.pagseguro.sandbox.token')
          );
        }else{
          $payment =  new Payment(
              config('payment.pagseguro.production.email'),
              config('payment.pagseguro.production.token')
          );
        }

        return Response::json([
            'session_id' => $payment->session()
        ]);
    }

    public function installments(Request $request)
    {
        $minParcel = 9999;
        $total = $request->get("total");
        $brand_name = $request->get("card_brand");
        $totalParcels = floor( $total / $minParcel );

        if( $totalParcels > 3){
          $totalParcels = 3;
        }

        $parcels = [];
        if( $totalParcels <= 1 ){
          $parcels[] = [
            'quantity' => 1,
            'installmentAmount' => $this->formatNumber($total),
            'totalAmount' => $this->formatNumber($total),
            'interestFree' => true
          ];
        }else{
          for( $i = 1; $i <= $totalParcels; $i++){
              $parcels[] = [
                'quantity' => $i,
                'installmentAmount' => $this->formatNumber( round( $total / $i, 2 ) ),
                'totalAmount' => $this->formatNumber($total),
                'interestFree' => true
              ];
          }
        }

        return Response::json([
            'error' => false,
            'installments' => [
              $brand_name => $parcels
            ]
        ]);
    }

    public function formatNumber($number){
      return number_format( $number, 2, ".","");
    }

}
