<?php

namespace ELucre\Payment\PagSeguro\Express;

use App, Config, Response;
use ELucre\Models\Order;
use ELucre\Models\PaymentType;
use ELucre\Payment\PagSeguro\Method;
use ELucre\Payment\PagSeguro\PaymentBase;
use ELucre\Payment\PagSeguro\Status;
use ELucre\Payment\PaymentMethod;
use PagSeguro\Domains\Requests\Payment as PagSeguroPayment;

class Payment extends PaymentMethod
{
    use PaymentBase;

    /**
     * payment_type_id
     *
     * @var int
     */
    public $payment_type_id = PaymentType::PAGSEGURO;

    /**
     * Setando o redirect como verdadeiro
     */
    protected $redirect = true;

    public function execute($order, $client, $request)
    {
        $payment = new PagSeguroPayment();
        $payment = $this->addBasePaymentInfos($payment, $order, $client, $request);

        try {
            $response = $payment->register($this->credentials(), true);

            $this->setCode($response->getCode());
            $this->setRedirectUrl('https://pagseguro.uol.com.br/v2/checkout/payment.html?code=' . $this->getCode());

            $order->finalize([
                'transaction_code' => $result->getCode(),
                'payment_type_id'  => $this->payment_type_id,
            ]);
        } catch (Exception $e) {
            \Log::error($e->getMessage());
        }
    }

    public function getTranscationByOrder($order)
    {
        return \PagSeguroTransactionSearchService::searchByReference($this->credentials, $order->id);
    }

    public function response()
    {
        return Response::json([
            'code' => $this->getCode()
        ]);
    }

    public function update(Order $order)
    {
        try {
            $transaction = $this->transaction($order->transaction_code);
            $this->updateOrderInfos($order, $transaction);
        }
        catch (Exception $e) {
            return false;
        }
    }
}
