<?php

namespace App\Domains\Payment\PagSeguro;

use App, Log, Input;
use App\Domains\Orders\Repositories\OrderRepository as OrderProductsRepository;
use Exception;
use Illuminate\Support\Facades\Response;
use PagSeguro\Services\Transactions\Notification;
use App\Domains\Payment\PagSeguro\CreditCard\Payment;

class PagSeguroNotificationService
{
    /**
     * @var ELucre\Repositories\OrderRepository
     */
    protected $orderProducts;

	/**
     * @var ELucre\Courses\OrderRepository
     */
    protected $orderEnrollments;

    /**
     * @var ELucre\Payment\PagSeguro\Payment
     */
    protected $payment;

    public function __construct(OrderProductsRepository $orderProducts)
    {
        $this->orderProducts = $orderProducts;
    }

    public function handle($code, $type)
    {
        try {

            if (env('TEST_PAGSEGURO') === true) {
                  $payment = new Payment(
                    config('payment.pagseguro.sandbox.email'),
                    config('payment.pagseguro.sandbox.token')
              );
            }else{
              $payment = new Payment(
                config('payment.pagseguro.production.email'),
                config('payment.pagseguro.production.token')
              );
            }

            $transaction = Notification::check($payment->credentials());

      			# buscando o pedido em compras de produtos
      			$order = $this->orderProducts->where('transaction_code',$transaction->getCode())->first();

            # buscando o pedido
            if (! $transaction || ! $order ) {
                return Response::json(['error' => 'order not found']);
            }

            # atualizando as informações de pagamento do pedido
            $payment->updateOrderInfos($order, $transaction);
        }
        catch (Exception $e) {

            Log::error('Erro na pagina de notificacao do PagSeguro: ' . $e->getMessage());
            Log::error('Transação: ' . $transaction->getReference() . ' | Status: ' . $transaction->getStatus() . ' | Método: ' . $transaction->getType());

            throw new Exception($e->getMessage());
        }
    }
}
