<?php

namespace App\Domains\Payment;

abstract class PaymentMethod
{
    /**
     * @var string
     */
    protected $code;

    /**
     * Flag que diz se meio de pagamento precisa redirecionar para algum site externo
     */
    protected $redirect = false;

    /**
     * Redirected URL
     */
    protected $redirectUrl;

    /**
     * Função para executar o pagamento
     * Cada meio tem o seu, precisa ser reescrito
     */
    abstract public function execute($order, $client, $request);

    /**
     * The HTTP response after the payment is executed
     */
    abstract public function response();

    public function getPaymentTypeId()
    {
        return $this->payment_type_id;
    }

    public function isRedirected()
    {
        return $this->redirect;
    }

    protected function setRedirectUrl($redirectUrl)
    {
        $this->redirectUrl = $redirectUrl;
        return $this;
    }

    public function getRedirectUrl()
    {
        return $this->redirectUrl;
    }

    public function setCode($code)
    {
        $this->code = $code;
        return $this;
    }

    public function getCode()
    {
        return $this->code;
    }

    public function shouldRemoveProductsFromStock()
    {
        return true;
    }
}
