<?php

namespace App\Domains\Users\Services;

use Carbon\Carbon;
use App\Domains\Users\Models\User;
use Laravel\Socialite\Facades\Socialite;
use App\Domains\Users\Exceptions\SocialAuthWithoutEmailException;

class SocialAuthService
{
    /**
     * @var bool
     */
    public $created = false;

    public function handle()
    {
        $social = Socialite::with('facebook')->user();

        if (! $social->getEmail()) {
            throw new SocialAuthWithoutEmailException;
        }

        if ($user = User::where('email', '=', $social->getEmail())->first()) {
            $user->updateLastLogin();
        } else {
            $user = User::create([
                'name'          => $social->getName(),
                'email'         => $social->getEmail(),
                'facebook_id'   => $social->getId(),
                'last_login_at' => Carbon::now(),
            ]);

            $this->created = true;
        }

        return $user;
    }

    public function wasCreated()
    {
        return $this->created;
    }
}
