<?php

namespace App\Http\Controllers\App;
use App\Services\IssabelService;
use App\Repositories\ServiceRepository;
use App\Repositories\DIDRepository;
use App\Repositories\CategoryRepository;
use App\Domains\Orders\Models\Order;
use Illuminate\Support\Str;
use Illuminate\Http\Request;

class CheckoutController extends Controller
{

	/**
		* @var App\Repositories\ServiceRepository
		*/
	 protected $services;

	 /**
 		* @var App\Repositories\DIDRepository
 		*/
 	 protected $dids;

	 /**
 		* @var App\Repositories\CategoryRepository
 		*/
 	 protected $categories;

	public function __construct(ServiceRepository $services, DIDRepository $dids, CategoryRepository $categories)
	{
		$this->services = $services;
		$this->dids = $dids;
		$this->webservice = new IssabelService();
		$this->categories = $categories;
	}

	/*
  * Inicializa a tela de checkout
  * @param string $slug Recebe o slug do plano selecionado
  */

	public function index($slug = null)
	{
		if($slug == null)
		{
			$service = $this->services->firstActive();
		}else{
			$service = $this->services->findOrFailBySlug($slug);
		}

		if(!$service)
		{
			return abort(404);
		}

		$checkoutKey = $this->getCheckoutKey();

		/*
	  Caso existam numeros previos atribuidos ao carrinho, faz a liberacao de todos
	  */

		$this->dids->removeReserved($checkoutKey);

		return view('app.checkout', [
			'page' => 'checkout',
			'service' => $service
		]);
	}

	/*
  Verifica se ha uma chave de sessao para o checkout e caso nao exista, cria uma nova
  */

	public function getCheckoutKey()
	{
		$checkoutKey = session('checkoutKey', null);
		if(!$checkoutKey)
		{
			$checkoutKey = str_random(35);
			session()->put('checkoutKey', $checkoutKey);
		}

		return $checkoutKey;
	}

	/*
  * Reserva um numero quando selecionado no checkout
	* @param Request $request recebe uma variavel da aplicacao com os dados enviados pelo usuario
  */

	public function reserve(Request $request)
	{
		$number = $request->get('number');
		$return = $this->dids->reserve($number, $this->getCheckoutKey());

		if($return)
		{
			return response()->json([
				'status' => 200
			]);
		}

		return response()->json([
			'status' => 422,
			'message' => 'O número selecionado já foi selecionado ou não está mais disponível'
		]);

	}

	/*
  * Faz a liberacao de um numero atribuido a uma sessao e que foi removido do checkout
	* @param Request $request recebe uma variavel da aplicacao com os dados enviados pelo usuario
  */

	public function release(Request $request)
	{
		$number = $request->get('number');
		$return = $this->dids->release($number);

	}

	/*
  * Faz a liberacao dos numeros atribuidos a uma sessao e que nao forem mais utilizados
	* @param object $request recebe uma variavel da aplicacao com os dados enviados pelo usuario
  */

	public function releaseMultiple(Request $request)
	{
		$numbers = $request->get('numbers');
		$return = $this->dids->releaseMultiple($numbers);

	}

	/*
  Retorna todos os dados necessarios para a criacao do checkout
  */

	public function plans()
	{

		return response()->json([
			'status' => 200,
			'plans' => $this->services->actives(),
			'cities' => $this->dids->cities(),
			'plans_0800' => $this->categories->plans_0800(),
			'extras' => $this->categories->aditionals(),
			'numbers_0800' => $this->dids->numbers_0800()
		]);
	}

	public function getToken()
	{
		$token = $this->webservice->getToken();
		return $token;
	}

}
