<?php

namespace App\Http\Controllers\Manager;

use App\Http\Requests;
use App\Repositories\ApplicationRepository;
use EscapeWork\Manager\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;

class applicationsController extends Controller
{
    /**
     * @var App\\Repositories\ApplicationRepository
     */
    protected $applications;

    public function __construct(ApplicationRepository $applications)
    {
        parent::__construct();

        $this->applications = $applications;
    }

    public function index(Request $request)
    {
        return view('manager.applications.index', [
            'applications' => $this->applications->manager($request),
        ]);
    }

    public function show($id)
    {
        return view('manager.applications.show', [
            'application' => $this->applications->findOrFail($id),
        ]);
    }

    public function curriculum($id)
    {
        $application = $this->applications->findOrFail($id);
        $path        = 'curriculums/' . $application->curriculum;

        $file = Storage::get($path);
        $type = Storage::mimeType($path);

        $response = response()->make($file, 200, [
            'Content-Type' => $type,
        ]);

        if ($type === 'application/octet-stream') {
            $response->header('Content-Disposition', 'attachment; filename=' . $application->curriculum);
        }

        return $response;
    }

    public function destroy($id)
    {
        $subscriber = $this->applications->findOrFail($id);
        $subscriber->delete();

        return redirect()->back()
            ->with('message', 'O lead <strong>' . $subscriber->name . '</strong> foi excluído com sucesso');
    }

    public function download($file)
    {
        return response()->download(storage_path('app/files/curriculums/' . $file));
    }
}
