<?php

namespace App\Http\Controllers\Manager;

use App\Http\Requests;
use App\Repositories\AwardRepository;
use EscapeWork\Manager\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Abouts;

class AwardsController extends Controller
{
    /**
     * @var App\Repositories\AwardRepository
     */
    protected $awards;

    public function __construct(AwardRepository $awards)
    {
        parent::__construct();

        $this->awards = $awards;
    }

    public function index(Request $request, Abouts $about)
    {
        session()->put('awards.url', $request->fullUrl());

        switch($about->id)
        {
          case 1:
            $title_page = 'Porque escolher';
            break;
          case 2:
            $title_page = $about->title;
            break;
          case 3:
            $title_page = 'Funcionalidades';
            break;
          case 4:
            $title_page = 'Funcionalidades Parceiros';
            break;
          case 5:
            $title_page = 'Funcionalidades Afiliados';
            break;
          default:
            $title_page = $about->title;
            break;
        }

        return view('manager.awards.index', [
            'awards' => $this->awards->manager($request, $about->id),
            'about' => $about,
            'title_page' => $title_page
        ]);
    }

    public function create(Request $request, Abouts $about)
    {
        $this->awards->fill($request->old());

        switch($about->id)
        {
          case 1:
            $title_page = 'Porque escolher';
            break;
          case 2:
            $title_page = $about->title;
            break;
          case 3:
            $title_page = 'Funcionalidades';
            break;
          case 4:
            $title_page = 'Funcionalidades Parceiros';
            break;
          case 5:
            $title_page = 'Funcionalidades Afiliados';
            break;
          default:
            $title_page = $about->title;
            break;
        }

        return view('manager.awards.create', [
            'award' => $this->awards,
            'about' => $about,
            'title_page' => $title_page
        ]);
    }

    public function store(Requests\AwardSaveRequest $request, Abouts $about)
    {
        $award = $this->awards->create($request->all());
        if($about->id == 1){
          $this->awards->uploadPicture($request->file('picture'));
        }else{
          $this->awards->uploadPicture($request->file('picture'));
        }

        return response()->manager([
            'route'   => session('awards.url', route('manager.awards.index', $about->id)),
            'message' => 'O registro <strong>'.$award->title.'</strong> foi inserido com sucesso',
        ]);
    }

    public function edit(Abouts $about, $id, Request $request)
    {
        $award = $this->awards->findOrFail($id);
        $award->fill($request->old());

        switch($about->id)
        {
          case 1:
            $title_page = 'Porque escolher';
            break;
          case 2:
            $title_page = $about->title;
            break;
          case 3:
            $title_page = 'Funcionalidades';
            break;
          case 4:
            $title_page = 'Funcionalidades Parceiros';
            break;
          case 5:
            $title_page = 'Funcionalidades Afiliados';
            break;
          default:
            $title_page = $about->title;
            break;
        }

        return view('manager.awards.edit', [
            'award' => $award,
            'about' => $about,
            'title_page' => $title_page
        ]);
    }

    public function update(Abouts $about, $id, Requests\AwardSaveRequest $request)
    {
        $award = $this->awards->update($id, $request->all());

        if($about->id == 1){
          $this->awards->uploadPicture($request->file('picture'));
        }else{
          $this->awards->uploadPicture($request->file('picture'));
        }

        return response()->manager([
            'route'   => session('awards.url', route('manager.awards.index', $about->id)),
            'message' => 'O registro <strong>'.$award->title.'</strong> foi atualizado com sucesso',
        ]);
    }

    public function updateBasic(Abouts $about, $id, Request $request)
    {
        $award = $this->awards->update($id, $request->all());

        return response()->manager([
            'route'   => session('awards.url', route('manager.awards.index', $about->id)),
            'message' => 'O registro <strong>'.$award->title.'</strong> foi atualizado com sucesso',
        ]);
    }

    public function destroy(Abouts $about, $id)
    {
        $award = $this->awards->destroy($id);

        return response()->manager([
            'back'    => true,
            'message' => 'O registro <strong>'.$award->title.'</strong> foi excluído com sucesso',
        ]);
    }
}
