<?php

namespace App\Http\Controllers\Manager;

use App\Http\Requests;
use App\Repositories\BannerRepository;
use EscapeWork\Manager\Http\Controllers\Controller;
use Illuminate\Http\Request;

class BannersController extends Controller
{
    /**
     * @var App\Repositories\BannerRepository
     */
    protected $banners;

    public function __construct(BannerRepository $banners)
    {
        parent::__construct();

        $this->banners = $banners;
    }

    public function index(Request $request)
    {
        return view('manager.banners.index', [
            'banners' => $this->banners->manager($request),
        ]);
    }

    public function create(Request $request)
    {
        $this->banners->fill($request->old());

        return view('manager.banners.create', [
            'banner' => $this->banners,
        ]);
    }

    public function store(Requests\BannerSaveRequest $request)
    {   
        $banner = $this->banners->create($request->all());
        $banner->uploadBlob($request->banner_blob,'banner');
        $banner->uploadBlob($request->banner_mobile_blob,'banner_mobile');
        $banner->uploadBlob($request->banner_cover_blob,'banner_cover');

        return response()->manager([
            'route'   => route('manager.banners.index'),
            'message' => 'O banner <strong>'.$this->banners->title.'</strong> foi inserido com sucesso',
        ]);
    }

    public function edit($id, Request $request)
    {
        $banner = $this->banners->find($id);
        $banner->fill($request->old());

        return view('manager.banners.edit', [
            'banner' => $banner,
        ]);
    }

    public function update($id, Requests\BannerSaveRequest $request)
    {
        $banner = $this->banners->update($id, $request->all());
        $banner->uploadBanner($request->file('banner'));
        $banner->uploadBannerMobile($request->file('banner_mobile'));
        $banner->uploadBlob($request->banner_cover_blob,'banner_cover');

        return response()->manager([
            'route'   => route('manager.banners.index'),
            'message' => 'O banner foi atualizado com sucesso',
        ]);
    }

    public function updateBasic($id, Request $request)
    {
        $this->banners->update($id, $request->all());

        return response()->manager([
            'route'   => route('manager.banners.index'),
            'message' => 'O banner <strong>'.$this->banners->title.'</strong> foi atualizado com sucesso',
        ]);
    }

    public function destroy($id)
    {
        $this->banners->destroy($id);

        return response()->manager([
            'back'    => true,
            'message' => 'O banner <strong>'.$this->banners->title.'</strong> foi excluído com sucesso',
        ]);
    }
}
