<?php

namespace App\Http\Controllers\Manager\Categories;

use App\Repositories\Services\BenefitRepository;
use EscapeWork\Manager\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Category;

class BenefitsController extends Controller
{
    protected $benefits;

    public function __construct(BenefitRepository $benefits)
    {
        parent::__construct();
        $this->benefits = $benefits;
    }

    public function index(Category $model, Request $request)
    {
        session()->put('benefits.url', $request->fullUrl());

        return view('manager.categories.benefits.index', [
            'benefits' => $this->benefits->manager($model, $request),
            'model' => $model
        ]);
    }

    public function create(Category $model, Request $request)
    {

        $this->benefits->fill($request->old());
        $this->benefits->model_id = $model->id;

        return view('manager.categories.benefits.create', [
            'benefit' => $this->benefits,
            'model' => $model
        ]);
    }

    public function store(Request $request)
    {
        $benefit = $this->benefits->create($request->all());
        $this->benefits->uploadPicture($request->file('picture'));

        return response()->manager([
            'route'   => session('benefits.url', route('manager.categories.benefits.index', $benefit->model_id)),
            'message' => 'O registro <strong>' . $benefit->title . '</strong> foi inserido com sucesso',
        ]);
    }

    public function edit(Category $model, $id, Request $request)
    {
        $benefit = $this->benefits->findOrFail($id);
        $benefit->fill($request->old());

        return view('manager.categories.benefits.edit', [
            'benefit' => $benefit,
            'model' => $model
        ]);
    }

    public function update(Category $model, $id, Request $request)
    {
        $benefit = $this->benefits->update($id, $request->all());
        $this->benefits->uploadPicture($request->file('picture'));

        return response()->manager([
            'route'   => session('benefits.url', route('manager.categories.benefits.index', $model->id)),
            'message' => 'O registro <strong>' . $benefit->title . '</strong> foi atualizado com sucesso',
        ]);
    }

    public function updateBasic(Category $model, $id, Request $request)
    {
        $benefit = $this->benefits->update($id, $request->all());

        return response()->manager([
            'route'   => session('benefits.url', route('manager.categories.benefits.index', $model->id)),
            'message' => 'O registro <strong>' . $benefit->title . '</strong> foi atualizado com sucesso',
        ]);
    }

    public function destroy(Category $model, $id)
    {
        $benefit = $this->benefits->destroy($id);

        return response()->manager([
            'back'    => true,
            'message' => 'O registro <strong>' . $benefit->title . '</strong> foi excluído com sucesso',
        ]);
    }
}
