<?php

namespace App\Http\Controllers\Manager;

use App\Http\Requests;
use App\Repositories\CategoryRepository;
use EscapeWork\Manager\Http\Controllers\Controller;
use Illuminate\Http\Request;

class CategoriesController extends Controller
{

    /**
     * @var App\Repositories\CategoryRepository
     */
    protected $categories;

    public function __construct(CategoryRepository $categories)
    {
        parent::__construct();

        $this->categories = $categories;
    }

    public function index(Request $request)
    {
        return view('manager.categories.index', [
            'categories' => $this->categories->manager($request),
        ]);
    }

    public function create(Request $request)
    {
        $this->categories->fill($request->old());

        return view('manager.categories.create', [
            'category' => $this->categories,
        ]);
    }

    public function store(Requests\CategorySaveRequest $request)
    {
        $this->categories->create($request->all());
        $this->categories->uploadBlob($request->banner_blob,'banner');
        $this->categories->uploadBlob($request->banner_mobile_blob,'banner_mobile');
        $this->categories->uploadBlob($request->picture_blob,'picture');

        return response()->manager([
            'route'   => route('manager.categories.index'),
            'message' => 'A categoria <strong>'.$this->categories->title.'</strong> foi inserida com sucesso',
        ]);
    }

    public function edit($id, Request $request)
    {
        $category = $this->categories->findOrFail($id);
        $category->fill($request->old());

        return view('manager.categories.edit', [
            'category' => $category,
        ]);
    }

    public function update($id, Requests\CategorySaveRequest $request)
    {
        $this->categories->update($id, $request->all());
        $this->categories->uploadBlob($request->banner_blob,'banner');
        $this->categories->uploadBlob($request->banner_mobile_blob,'banner_mobile');
        $this->categories->uploadBlob($request->picture_blob,'picture');

        return response()->manager([
            'route'   => route('manager.categories.index'),
            'message' => 'A categoria <strong>'.$this->categories->title.'</strong> foi atualizada com sucesso',
        ]);
    }

    public function updateBasic($id, Request $request)
    {
        $this->categories->update($id, $request->all());

        return response()->manager([
            'route'   => route('manager.categories.index'),
            'message' => 'A categoria <strong>'.$this->categories->title.'</strong> foi atualizada com sucesso',
        ]);
    }

    public function destroy($id)
    {
        $this->categories->destroy($id);

        return response()->manager([
            'back'    => true,
            'message' => 'A categoria <strong>'.$this->categories->title.'</strong> foi excluída com sucesso',
        ]);
    }
}
