<?php

namespace App\Http\Controllers\Manager;

use App\Http\Requests;
use App\Repositories\DIDRepository;
use EscapeWork\Manager\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Imports\DIDImporter;
use Maatwebsite\Excel\Facades\Excel;

class DIDController extends Controller
{

    /**
     * @var App\Repositories\DIDRepository
     */
    protected $dids;

    public function __construct(DIDRepository $dids)
    {
        parent::__construct();

        $this->dids = $dids;
    }

    public function index(Request $request)
    {
        return view('manager.dids.index', [
            'dids' => $this->dids->manager($request),
        ]);
    }

    public function create(Request $request)
    {
        $this->dids->fill($request->old());

        return view('manager.dids.create', [
            'did' => $this->dids,
        ]);
    }

    public function import(Request $request)
    {
        $this->dids->fill($request->old());

        return view('manager.dids.import', [
            'did' => $this->dids,
        ]);
    }

    public function importStore(Request $request)
    {
  
         $file = $request->file('file');
         Excel::import(new DIDImporter, $file);

         return response()->manager([
             'route'   => route('manager.dids.index'),
             'message' => 'O arquivo foi importado com sucesso',
         ]);

    }

    public function store(Requests\DIDSaveRequest $request)
    {
        $this->dids->create($request->all());

        return response()->manager([
            'route'   => route('manager.dids.index'),
            'message' => 'O registro <strong>'.$this->dids->title.'</strong> foi inserido com sucesso',
        ]);
    }

    public function edit($id, Request $request)
    {
        $did = $this->dids->findOrFail($id);
        $did->fill($request->old());

        return view('manager.dids.edit', [
            'did' => $did,
        ]);
    }

    public function update($id, Requests\DIDSaveRequest $request)
    {
        $this->dids->update($id, $request->all());

        return response()->manager([
            'route'   => route('manager.dids.index'),
            'message' => 'O registro <strong>'.$this->dids->title.'</strong> foi atualizado com sucesso',
        ]);
    }

    public function updateBasic($id, Request $request)
    {
        $this->dids->update($id, $request->all());

        return response()->manager([
            'route'   => route('manager.dids.index'),
            'message' => 'O registro <strong>'.$this->dids->title.'</strong> foi atualizado com sucesso',
        ]);
    }

    public function destroy($id)
    {
        $this->dids->destroy($id);

        return response()->manager([
            'back'    => true,
            'message' => 'O registro <strong>'.$this->dids->title.'</strong> foi excluído com sucesso',
        ]);
    }
}
