<?php

namespace App\Http\Controllers\Manager;

use App\Http\Requests;
use App\Repositories\DownloadCategoryRepository;
use App\Repositories\DownloadRepository;
use EscapeWork\Manager\Http\Controllers\Controller;
use Illuminate\Http\Request;

class DownloadsController extends Controller
{

    /**
     * @var App\Repositories\DownloadRepository
     */
    protected $downloads;

    /**
     * @var App\Repositories\DownloadCategoryRepository
     */
    protected $categories;

    public function __construct(
        DownloadRepository $downloads,
        DownloadCategoryRepository $categories)
    {
        parent::__construct();

        $this->downloads  = $downloads;
        $this->categories = $categories;
    }

    public function index(Request $request)
    {
        return view('manager.downloads.index', [
            'categories' => $this->categories->all(),
            'downloads'  => $this->downloads->manager($request),
        ]);
    }

    public function create(Request $request)
    {
        $this->downloads->fill($request->old());

        return view('manager.downloads.create', [
            'categories' => $this->categories->all(),
            'download'   => $this->downloads,
        ]);
    }

    public function store(Requests\DownloadSaveRequest $request)
    {
        $this->downloads->create($request->all());
        $this->downloads->uploadFile($request->file('file'));

        return response()->manager([
            'route'   => route('manager.downloads.index'),
            'message' => 'O download <strong>'.$this->downloads->title.'</strong> foi inserido com sucesso',
        ]);
    }

    public function edit($id, Request $request)
    {
        $download = $this->downloads->findOrFail($id);
        $download->fill($request->old());

        return view('manager.downloads.edit', [
            'categories' => $this->categories->all(),
            'download'   => $download,
        ]);
    }

    public function update($id, Requests\DownloadSaveRequest $request)
    {
        $this->downloads->update($id, $request->all());
        $this->downloads->uploadFile($request->file('file'));

        return response()->manager([
            'route'   => route('manager.downloads.index'),
            'message' => 'O download <strong>'.$this->downloads->title.'</strong> foi atualizado com sucesso',
        ]);
    }

    public function updateBasic($id, Request $request)
    {
        $this->downloads->update($id, $request->all());

        return response()->manager([
            'route'   => route('manager.downloads.index'),
            'message' => 'O download <strong>'.$this->downloads->title.'</strong> foi atualizado com sucesso',
        ]);
    }

    public function destroy($id)
    {
        $this->downloads->destroy($id);

        return response()->manager([
            'route'   => route('manager.downloads.index'),
            'message' => 'O download <strong>'.$this->downloads->title.'</strong> foi excluído com sucesso',
        ]);
    }
}
