<?php

namespace App\Http\Controllers\Manager\Faqs;

use App\Repositories\FaqRepository;
use EscapeWork\Manager\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Service;

class ServicesController extends Controller
{
    protected $faqs;

    public function __construct(FaqRepository $faqs)
    {
        parent::__construct();

        $this->faqs = $faqs;
    }


    public function index(Service $model, Request $request)
    {

        session()->put('faqs.url', $request->fullUrl());

        return view('manager.faqs.services.index', [
            'faqs' => $this->faqs->manager($model, $request),
            'model' => $model
        ]);
    }

    public function create(Service $model, Request $request)
    {

        $this->faqs->fill($request->old());
        $this->faqs->model_id = $model->id;
        $this->faqs->faq_model = get_class($model);

        return view('manager.faqs.services.create', [
            'faq' => $this->faqs,
            'model' => $model
        ]);
    }

    public function store(Request $request)
    {
        $faq = $this->faqs->create($request->all());

        return response()->manager([
            'route'   => session('faqs.url', route('manager.faqs.services.index', $faq->model_id)),
            'message' => 'O registro <strong>' . $faq->question . '</strong> foi inserido com sucesso',
        ]);
    }

    public function edit(Service $model, $id, Request $request)
    {
        $faq = $this->faqs->findOrFail($id);
        $faq->fill($request->old());

        return view('manager.faqs.services.edit', [
            'faq' => $faq,
            'model' => $model
        ]);
    }

    public function update(Service $model, $id, Request $request)
    {
        $faq = $this->faqs->update($id, $request->all());

        return response()->manager([
            'route'   => session('faqs.url', route('manager.faqs.services.index', $model->id)),
            'message' => 'O registro <strong>' . $faq->question . '</strong> foi atualizado com sucesso',
        ]);
    }

    public function updateBasic(Service $model, $id, Request $request)
    {
        $faq = $this->faqs->update($id, $request->all());

        return response()->manager([
            'route'   => session('faqs.url', route('manager.faqs.services.index', $model->id)),
            'message' => 'O registro <strong>' . $faq->question . '</strong> foi atualizado com sucesso',
        ]);
    }

    public function destroy(Service $model, $id)
    {
        $faq = $this->faqs->destroy($id);

        return response()->manager([
            'back'    => true,
            'message' => 'O registro <strong>' . $faq->question . '</strong> foi excluído com sucesso',
        ]);
    }
}
