<?php

namespace App\Http\Controllers\Manager;

use App\Http\Requests;
use App\Repositories\NewsCategoryRepository;
use EscapeWork\Manager\Http\Controllers\Controller;
use Illuminate\Http\Request;

class NewsCategoriesController extends Controller
{

    /**
     * @var App\Repositories\NewsCategoryRepository
     */
    protected $news_categories;

    public function __construct(NewsCategoryRepository $news_categories)
    {
        parent::__construct();

        $this->news_categories = $news_categories;
    }

    public function index(Request $request)
    {
        return view('manager.news_categories.index', [
            'news_categories' => $this->news_categories->manager($request),
        ]);
    }

    public function create(Request $request)
    {
        $this->news_categories->fill($request->old());

        return view('manager.news_categories.create', [
            'category' => $this->news_categories,
        ]);
    }

    public function store(Requests\NewsCategorySaveRequest $request)
    {
        $this->news_categories->create($request->all());

        return response()->manager([
            'route'   => route('manager.news_categories.index'),
            'message' => 'A categoria <strong>'.$this->news_categories->title.'</strong> foi inserida com sucesso',
        ]);
    }

    public function edit($id, Request $request)
    {
        $news_category = $this->news_categories->findOrFail($id);
        $news_category->fill($request->old());

        return view('manager.news_categories.edit', [
            'category' => $news_category,
        ]);
    }

    public function update($id, Requests\NewsCategorySaveRequest $request)
    {
        $this->news_categories->update($id, $request->all());

        return response()->manager([
            'route'   => route('manager.news_categories.index'),
            'message' => 'A categoria de notícia <strong>'.$this->news_categories->title.'</strong> foi atualizada com sucesso',
        ]);
    }

    public function updateBasic($id, Request $request)
    {
        $this->news_categories->update($id, $request->all());

        return response()->manager([
            'route'   => route('manager.news_categories.index'),
            'message' => 'A categoria de notícia <strong>'.$this->news_categories->title.'</strong> foi atualizada com sucesso',
        ]);
    }

    public function destroy($id)
    {
        $this->news_categories->destroy($id);

        return response()->manager([
            'back'    => true,
            'message' => 'A categoria <strong>'.$this->news_categories->title.'</strong> foi excluída com sucesso',
        ]);
    }
}
