<?php

namespace App\Http\Controllers\Manager;

use EscapeWork\Manager\Http\Controllers\Controller;
use App\Repositories\NewsRepository;
use App\Repositories\NewsCategoryRepository;
use Illuminate\Http\Request;
use App\Http\Requests;

class NewsController extends Controller
{

    /**
     * @var App\Repositories\NewsRepository
     */
    protected $news;

    /**
     * @var App\Repositories\NewsCategoryRepository
     */
    protected $categories;

    public function __construct(NewsRepository $news, NewsCategoryRepository $categories)
    {
        parent::__construct();

        $this->news = $news;
        $this->categories = $categories;
    }

    public function index(Request $request)
    {
        return view('manager.news.index', [
            'news' => $this->news->manager($request),
            'categories' => $this->categories->all()
        ]);
    }

    public function create(Request $request)
    {
        $news = $this->news->getModel();
        $news->fill($request->old());

        return view('manager.news.create', [
            'news' => $news,
            'categories' => $this->categories->all()
        ]);
    }

    public function store(Requests\NewsSaveRequest $request)
    {
        $news = $this->news->create($request->all());
        $this->news->uploadPicture($request->file('picture'));
        $this->news->uploadBlob($request->folder_blob,'folder');

        if ($request->hasFile('pictures')) {
            $news->uploadMultipleMedias($request->file('pictures'));
        }

        return response()->manager([
            'route'   => route('manager.news.index'),
            'message' => 'A notícia <strong>'.$news->title.'</strong> foi inserida com sucesso',
        ]);
    }

    public function edit($id, Request $request)
    {
        $news = $this->news->findOrFail($id);
        $news->fill($request->old());

        return view('manager.news.edit', [
            'news' => $news,
            'categories' => $this->categories->all()
        ]);
    }

    public function update($id, Requests\NewsSaveRequest $request)
    {
        $news = $this->news->update($id, $request->all());
        $this->news->uploadPicture($request->file('picture'));
        $this->news->uploadBlob($request->folder_blob,'folder');

        if ($request->hasFile('pictures')) {
            $news->uploadMultipleMedias($request->file('pictures'));
        }

        return response()->manager([
            'route'   => route('manager.news.index'),
            'message' => 'A notícia <strong>'.$news->title.'</strong> foi atualizada com sucesso',
        ]);
    }

    public function updateBasic($id, Request $request)
    {
        $news = $this->news->update($id, $request->all());

        return response()->manager([
            'route'   => route('manager.news.index'),
            'message' => 'A notícia <strong>'.$news->title.'</strong> foi atualizada com sucesso',
        ]);
    }

    public function destroy($id)
    {
        $news = $this->news->destroy($id);

        return response()->manager([
            'back'    => true,
            'message' => 'A notícia <strong>'.$news->title.'</strong> foi excluída com sucesso',
        ]);
    }
}
