<?php

namespace App\Http\Controllers\Manager;

use App\Domains\Orders\Repositories\OrderRepository;
use EscapeWork\Manager\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Domains\Orders\Notifications\OrderCreatedNotification;
use App\Domains\Orders\Notifications\OrderPaidNotification;
use App\Domains\Orders\Notifications\OrderCancelledNotification;
use App\Domains\Orders\Mailers\OrderCreatedAdminMail;
use App\Domains\Orders\Mailers\OrderUpdatedAdminMail;
use App\Domains\Orders\Mailers\OrderPaidFinanceiroMail;
use Illuminate\Support\Facades\Mail;
use App\Services\IssabelService;
use App\Models\DID;

class OrdersController extends Controller
{

    /**
     * @var App\Domains\Orders\Repositories\OrderRepository
     */
    protected $orders;

    public function __construct(OrderRepository $orders)
    {
        parent::__construct();

        $this->orders = $orders;
    }

    public function index(Request $request)
    {
        return view('manager.orders.index', [
            'orders' => $this->orders->manager($request),
        ]);
    }

    public function approve($id)
    {
        $order = $this->orders->findOrFail($id);
        $order->status_id = 2;
        $order->save();

        $order->user->notify(new OrderPaidNotification($order));

        Mail::to(config('mail.to'))->send(new OrderUpdatedAdminMail($order));
        Mail::to(config('mail.to_financeiro'))->send(new OrderPaidFinanceiroMail($order));

        echo "Ordem aprovada";

    }

    public function cancel($id)
    {

        $order = $this->orders->findOrFail($id);
        $order->status_id = 5;
        $order->save();

        $webservice = new IssabelService();

        // remove rocs
        $rocs = json_decode($order->getData('issabel_rocs'));
        foreach($rocs as $did)
        {
          $webservice->removeDID($did->id);
          $localDID = app(DID::class)->find($did->local_id);
          $localDID->available = 1;
          $localDID->user_id = null;
          $localDID->save();
        }

        // remove 0800
        $n0800 = json_decode($order->getData('issabel_0800'));
        foreach($n0800 as $did)
        {
          $webservice->removeDID($did->id);
          $localDID = app(DID::class)->find($did->local_id);
          $localDID->available = 1;
          $localDID->user_id = null;
          $localDID->save();
        }

        // remove user
        $webservice->removeUser($order->getData('issabel_login_id'));

        // remove company
        $webservice->removeCompany($order->getData('issabel_company_id'));

        $order->user->notify(new OrderCancelledNotification($order));
        Mail::to(config('mail.to'))->send(new OrderUpdatedAdminMail($order));

        echo "Ordem cancelada";

    }

    public function show($id)
    {
        return view('manager.orders.show', [
            'order' => $this->orders->findOrFail($id),
        ]);
    }

    public function destroy($id)
    {
        $contact = $this->contacts->findOrFail($id);
        $contact->delete();

        return redirect()->back()
                         ->with('message', 'O contato foi excluído com sucesso!');
    }
}
