<?php

namespace App\Http\Controllers\Manager;

use App\Http\Requests;
use App\Repositories\PartnerRepository;
use EscapeWork\Manager\Http\Controllers\Controller;
use Illuminate\Http\Request;

class PartnersController extends Controller
{

    /**
     * @var App\Repositories\PartnerRepository
     */
    protected $partners;

    public function __construct(PartnerRepository $partners)
    {
        parent::__construct();

        $this->partners = $partners;
    }

    public function index(Request $request)
    {
        return view('manager.partners.index', [
            'partners' => $this->partners->manager($request),
        ]);
    }

    public function create(Request $request)
    {
        $this->partners->fill($request->old());

        return view('manager.partners.create', [
            'partner' => $this->partners,
        ]);
    }

    public function store(Requests\PartnerSaveRequest $request)
    {
        $this->partners->create($request->all());
        $this->partners->uploadPicture($request->file('picture'));

        return response()->manager([
            'route'   => route('manager.partners.index'),
            'message' => 'O parceiro foi inserido com sucesso',
        ]);
    }

    public function edit($id, Request $request)
    {
        $partner = $this->partners->findOrFail($id);
        $partner->fill($request->old());

        return view('manager.partners.edit', [
            'partner' => $partner,
        ]);
    }

    public function update($id, Requests\PartnerSaveRequest $request)
    {
        $this->partners->update($id, $request->all());
        $this->partners->uploadPicture($request->file('picture'));

        return response()->manager([
            'route'   => route('manager.partners.index'),
            'message' => 'O parceiro foi atualizado com sucesso',
        ]);
    }

    public function updateBasic($id, Request $request)
    {
        $this->partners->update($id, $request->all());

        return response()->manager([
            'route'   => route('manager.partners.index'),
            'message' => 'O parceiro foi atualizado com sucesso',
        ]);
    }

    public function destroy($id)
    {
        $this->partners->destroy($id);

        return response()->manager([
            'back'    => true,
            'message' => 'O parceiro foi excluído com sucesso',
        ]);
    }
}
