<?php

namespace App\Http\Controllers\Manager;

use App\Http\Requests;
use App\Repositories\RegionsRepository;
use EscapeWork\Manager\Http\Controllers\Controller;
use Illuminate\Http\Request;

class RegionsController extends Controller
{

    /**
     * @var App\Repositories\RegionsRepository
     */
    protected $regions;

    public function __construct(RegionsRepository $regions)
    {
        parent::__construct();

        $this->regions = $regions;
    }

    public function index(Request $request)
    {

        return view('manager.regions.index', [
            'regions' => $this->regions->manager($request)
        ]);
    }

    public function create(Request $request)
    {
        $this->regions->fill($request->old());

        return view('manager.regions.create', [
            'old' => $this->regions,
            'regions' => $this->regions->all()
        ]);
    }

    public function store(Requests\RegionsSaveRequest $request)
    {
        $this->regions->create($request->all());

        return response()->manager([
            'route'   => route('manager.regions.index'),
            'message' => 'A categoria <strong>'.$this->regions->title.'</strong> foi inserida com sucesso',
        ]);
    }

    public function edit($id, Request $request)
    {
        $region = $this->regions->findOrFail($id);
        $region->fill($request->old());

        return view('manager.regions.edit', [
            'region' => $region,
            'regions' => $this->regions->all()
        ]);
    }

    public function update($id, Requests\RegionsSaveRequest $request)
    {

        $this->regions->update($id, $request->all());

        return response()->manager([
            'route'   => route('manager.regions.index'),
            'message' => 'A categoria <strong>'.$this->regions->title.'</strong> foi atualizada com sucesso',
        ]);
    }

    public function updateBasic($id, Request $request)
    {
        $this->regions->update($id, $request->all());

        return response()->manager([
            'route'   => route('manager.regions.index'),
            'message' => 'A categoria <strong>'.$this->regions->title.'</strong> foi atualizada com sucesso',
        ]);
    }

    public function destroy($id)
    {
        $this->regions->destroy($id);

        return response()->manager([
            'back'    => true,
            'message' => 'A categoria <strong>'.$this->regions->title.'</strong> foi excluída com sucesso',
        ]);
    }
}
