<?php

namespace App\Http\Controllers\Manager;

use App\Http\Requests;
use App\Repositories\SectionsRepository;
use EscapeWork\Manager\Http\Controllers\Controller;
use Illuminate\Http\Request;

class SectionsController extends Controller
{

    /**
     * @var App\Repositories\SectionsRepository
     */
    protected $sections;

    public function __construct(SectionsRepository $sections)
    {
        parent::__construct();

        $this->sections = $sections;
    }

    public function index(Request $request)
    {
        return view('manager.sections.index', [
            'sections' => $this->sections->manager($request)
        ]);
    }

    public function create(Request $request)
    {
        $this->sections->fill($request->old());

        return view('manager.sections.create', [
            'section' => $this->sections
        ]);
    }

    public function store(Requests\SectionsSaveRequest $request)
    {
        $this->sections->create($request->all());

        return response()->manager([
            'route'   => route('manager.sections.index'),
            'message' => 'A categoria <strong>'.$this->sections->title.'</strong> foi inserida com sucesso',
        ]);
    }

    public function edit($id, Request $request)
    {
        $section = $this->sections->findOrFail($id);
        $section->fill($request->old());

        return view('manager.sections.edit', [
            'section' => $section,
            'sections' => $this->sections->all()
        ]);
    }

    public function update($id, Requests\SectionsSaveRequest $request)
    {
        $this->sections->update($id, $request->all());

        return response()->manager([
            'route'   => route('manager.sections.index'),
            'message' => 'A categoria <strong>'.$this->sections->title.'</strong> foi atualizada com sucesso',
        ]);
    }

    public function updateBasic($id, Request $request)
    {
        $this->sections->update($id, $request->all());

        return response()->manager([
            'route'   => route('manager.sections.index'),
            'message' => 'A categoria <strong>'.$this->sections->title.'</strong> foi atualizada com sucesso',
        ]);
    }

    public function destroy($id)
    {
        $this->sections->destroy($id);

        return response()->manager([
            'back'    => true,
            'message' => 'A categoria <strong>'.$this->sections->title.'</strong> foi excluída com sucesso',
        ]);
    }
}
