<?php

namespace App\Http\Controllers\Manager;

use App\Http\Requests;
use App\Repositories\ServiceRepository;
use App\Repositories\CategoryRepository;

use EscapeWork\Manager\Http\Controllers\Controller;
use Illuminate\Http\Request;

class ServicesController extends Controller
{

    /**
     * @var App\Repositories\ServiceRepository
     */
    protected $services;

    /**
     * @var App\Repositories\CategoryRepository
     */
    protected $categories;

    public function __construct(ServiceRepository $services, CategoryRepository $categories)
    {
        parent::__construct();

        $this->services = $services;
        $this->categories = $categories;
    }

    public function index(Request $request)
    {
        return view('manager.services.index', [
            'services' => $this->services->manager($request),
        ]);
    }

    public function create(Request $request)
    {
        $this->services->fill($request->old());

        return view('manager.services.create', [
            'service' => $this->services,
            'categories' => $this->categories->get()
        ]);
    }

    public function store(Requests\ServiceSaveRequest $request)
    {
        $this->services->create($request->all());
        $this->services->uploadBlob($request->banner_blob,'banner');
        $this->services->uploadBlob($request->banner_mobile_blob,'banner_mobile');
        $this->services->uploadBlob($request->picture_blob,'picture');
        $this->services->uploadIcon($request->icon);

        $this->services->categories()->sync($request->categories);

        return response()->manager([
            'route'   => route('manager.services.index'),
            'message' => 'A categoria <strong>'.$this->services->title.'</strong> foi inserida com sucesso',
        ]);
    }

    public function edit($id, Request $request)
    {
        $service = $this->services->findOrFail($id);
        $service->fill($request->old());

        return view('manager.services.edit', [
            'service' => $service,
            'categories' => $this->categories->get()
        ]);
    }

    public function update($id, Requests\ServiceSaveRequest $request)
    {
        $service = $this->services->update($id, $request->all());
        $this->services->uploadBlob($request->banner_blob,'banner');
        $this->services->uploadBlob($request->banner_mobile_blob,'banner_mobile');
        $this->services->uploadBlob($request->picture_blob,'picture');
        $this->services->uploadIcon($request->icon);
        
        $this->services->categories()->sync($request->categories);

        return response()->manager([
            'route'   => route('manager.services.index'),
            'message' => 'A categoria <strong>'.$this->services->title.'</strong> foi atualizada com sucesso',
        ]);
    }

    public function updateBasic($id, Request $request)
    {
        $this->services->update($id, $request->all());

        return response()->manager([
            'route'   => route('manager.services.index'),
            'message' => 'A categoria <strong>'.$this->services->title.'</strong> foi atualizada com sucesso',
        ]);
    }

    public function destroy($id)
    {
        $this->services->destroy($id);

        return response()->manager([
            'back'    => true,
            'message' => 'A categoria <strong>'.$this->services->title.'</strong> foi excluída com sucesso',
        ]);
    }
}
