<?php

namespace App\Http\Controllers\Manager;

use App\Http\Requests;
use App\Repositories\TestimonialRepository;
use EscapeWork\Manager\Http\Controllers\Controller;
use Illuminate\Http\Request;

class TestimonialsController extends Controller
{
    /**
     * @var App\Repositories\TestimonialRepository
     */
    protected $testimonials;

    public function __construct(TestimonialRepository $testimonials)
    {
        parent::__construct();

        $this->testimonials = $testimonials;
    }

    public function index(Request $request)
    {
        session()->put('testimonials.url', $request->fullUrl());

        return view('manager.testimonials.index', [
            'testimonials' => $this->testimonials->manager($request),
        ]);
    }

    public function create(Request $request)
    {
        $this->testimonials->fill($request->old());

        return view('manager.testimonials.create', [
            'testimonial' => $this->testimonials,
        ]);
    }

    public function store(Requests\TestimonialSaveRequest $request)
    {
        $testimonial = $this->testimonials->create($request->all());

        if ($request->hasFile('logo')) {
            $testimonial->uploadLogo($request->file('logo'));
        }

        return response()->manager([
            'route'   => session('testimonials.url', route('manager.testimonials.index')),
            'message' => 'O depoimento <strong>'.$testimonial->title.'</strong> foi inserido com sucesso',
        ]);
    }

    public function edit($id, Request $request)
    {
        $testimonial = $this->testimonials->findOrFail($id);
        $testimonial->fill($request->old());

        return view('manager.testimonials.edit', [
            'testimonial' => $testimonial,
        ]);
    }

    public function update($id, Requests\TestimonialSaveRequest $request)
    {
        $testimonial = $this->testimonials->update($id, $request->all());

        if ($request->hasFile('logo')) {
            $testimonial->uploadLogo($request->file('logo'));
        }

        return response()->manager([
            'route'   => session('testimonials.url', route('manager.testimonials.index')),
            'message' => 'O depoimento <strong>'.$testimonial->title.'</strong> foi atualizado com sucesso',
        ]);
    }

    public function updateBasic($id, Request $request)
    {
        $testimonial = $this->testimonials->update($id, $request->all());

        return response()->manager([
            'route'   => session('testimonials.url', route('manager.testimonials.index')),
            'message' => 'O depoimento <strong>'.$testimonial->title.'</strong> foi atualizado com sucesso',
        ]);
    }

    public function destroy($id)
    {
        $testimonial = $this->testimonials->destroy($id);

        return response()->manager([
            'back'    => true,
            'message' => 'O depoimento <strong>'.$testimonial->title.'</strong> foi excluído com sucesso',
        ]);
    }
}
