<?php

namespace App\Http\Controllers\Manager;

use Illuminate\Http\Request;
use App\Http\Requests;
use App\Repositories\UserRepository;
use App\Http\Requests\UserStoreRequest;
use App\Http\Requests\UserUpdateRequest;
use EscapeWork\Manager\Http\Controllers\Controller;

class UsersController extends Controller
{

    /**
     * @var App\Repositories\UserRepository
     */
    protected $users;

    public function __construct(UserRepository $users)
    {
        parent::__construct();

        $this->users = $users;
    }

    public function index(Request $request)
    {
        return view('manager.users.index', [
            'users' => $this->users->manager($request),
        ]);
    }

    public function create(Request $request)
    {
        $this->users->fill($request->old());

        return view('manager.users.create', [
            'user' => $this->users,
        ]);
    }

    public function store(UserStoreRequest $request)
    {
        $user = $this->users->create($request->all());

        return response()->manager([
            'route'   => route('manager.users.index'),
            'message' => 'O usuário <strong>'.$user->name.'</strong> foi inserido com sucesso',
        ]);
    }

    public function edit($id, Request $request)
    {
        $user = $this->users->findOrFail($id);
        $user->fill($request->old());

        return view('manager.users.edit', [
            'user' => $user,
        ]);
    }

    public function update($id, UserUpdateRequest $request)
    {
        $user = $this->users->update($id, $request->all());

        return response()->manager([
            'route'   => route('manager.users.index'),
            'message' => 'O usuário <strong>'.$user->name.'</strong> foi atualizado com sucesso',
        ]);
    }

    public function updateBasic($id, Request $request)
    {
        $user = $this->users->update($id, $request->all());

        return response()->manager([
            'route'   => route('manager.users.index'),
            'message' => 'O usuário <strong>'.$user->name.'</strong> foi atualizado com sucesso',
        ]);
    }

    public function destroy($id)
    {
        $this->users->destroy($id);

        return response()->manager([
            'back'    => true,
            'message' => 'O usuário <strong>'.$this->users->name.'</strong> foi excluído com sucesso',
        ]);
    }
}
