<?php

namespace App\Http\Controllers\Manager;

use App\Http\Requests;
use App\Repositories\VacantjobRepository;
use EscapeWork\Manager\Http\Controllers\Controller;
use Illuminate\Http\Request;

class VacantjobsController extends Controller
{
    /**
     * @var App\Repositories\VacantjobRepository
     */
    protected $vacantjobs;

    public function __construct(VacantjobRepository $vacantjobs)
    {
        parent::__construct();

        $this->vacantjobs = $vacantjobs;
    }

    public function index(Request $request)
    {
        session()->put('vacantjobs.url', $request->fullUrl());

        return view('manager.vacantjobs.index', [
            'vacantjobs' => $this->vacantjobs->manager($request),
        ]);
    }

    public function create(Request $request)
    {
        $this->vacantjobs->fill($request->old());

        return view('manager.vacantjobs.create', [
            'vacantjob' => $this->vacantjobs,
        ]);
    }

    public function store(Requests\VacantjobSaveRequest $request)
    {
        $vacantjob = $this->vacantjobs->create($request->all());

        return response()->manager([
            'route'   => session('vacantjobs.url', route('manager.vacantjobs.index')),
            'message' => 'O vaga <strong>'.$vacantjob->title.'</strong> foi inserido com sucesso',
        ]);
    }

    public function edit($id, Request $request)
    {
        $vacantjob = $this->vacantjobs->findOrFail($id);
        $vacantjob->fill($request->old());

        return view('manager.vacantjobs.edit', [
            'vacantjob' => $vacantjob,
        ]);
    }

    public function update($id, Requests\VacantjobSaveRequest $request)
    {
        $vacantjob = $this->vacantjobs->update($id, $request->all());

        return response()->manager([
            'route'   => session('vacantjobs.url', route('manager.vacantjobs.index')),
            'message' => 'O vaga <strong>'.$vacantjob->title.'</strong> foi atualizado com sucesso',
        ]);
    }

    public function updateBasic($id, Request $request)
    {
        $vacantjob = $this->vacantjobs->update($id, $request->all());

        return response()->manager([
            'route'   => session('vacantjobs.url', route('manager.vacantjobs.index')),
            'message' => 'O vaga <strong>'.$vacantjob->title.'</strong> foi atualizado com sucesso',
        ]);
    }

    public function destroy($id)
    {
        $vacantjob = $this->vacantjobs->destroy($id);

        return response()->manager([
            'back'    => true,
            'message' => 'O vaga <strong>'.$vacantjob->title.'</strong> foi excluído com sucesso',
        ]);
    }
}
