<?php

namespace App\Models;

use App\Presenters\ApplicationPresenter;
use EscapeWork\LaravelSteroids\Model;
use EscapeWork\LaravelSteroids\Presentable;
use App\Models\ProfessionalExperience;
use App\Domains\Data\Datable;
use EscapeWork\LaraMedias\Traits\Medias;

class Application extends Model
{
    use Presentable, Datable, Medias;

    /**
     * Table
     */
    protected $table = 'applications';

    /**
     * Fillable fields
     */
    protected $fillable = [
        'name',
        'phone',
        'email',
        'curriculum',
        'state',
        'city',
        'url',
        'interests'
    ];

    protected $dates = [
        'birthday',
    ];

    /**
     * Presenter
     */
    protected $presenter = ApplicationPresenter::class;

    public function experiences()
    {
        return $this->hasMany("App\Models\ProfessionalExperience", "application_id");
    }

    public function vacantjob()
    {
        return $this->belongsTo("App\Models\Vacantjob", "vacancy");
    }

    public function uploadCurriculum($curriculum)
    {
        $uploader = app('EscapeWork\LaravelSteroids\Upload');
        $filename = $uploader->to('files/curriculums')
            ->execute($curriculum);

        $this->curriculum = $filename;
        $this->save();
        return $filename;
    }

    public function setBirthdayAttribute($date)
    {
        return $this->_setDateAttribute('birthday', $date);
    }

    public static function register($request)
    {
        //dd($request->all());

        $request_all = $request->all();
        $application = Application::create($request_all);
        $application->experiences()->saveMany(
            array_map(
                function ($name, $phone, $admission, $dismissal, $salary, $exit) use ($application) {
                    return new ProfessionalExperience([
                        'application_id' => $application->id,
                        'company_name' => $name,
                        'company_phone' => $phone,
                        'company_admission' => $admission,
                        'company_dismissal' => $dismissal,
                        'company_salary' => $salary,
                        'company_exit' => $exit,
                    ]);
                },
                $request->get('company_name'),
                $request->get('company_phone'),
                $request->get('company_admission'),
                $request->get('company_dismissal'),
                $request->get('company_salary'),
                $request->get('company_exit')
            )
        );

        if ($request->hasFile('curriculum')) {
            $application->uploadCurriculum($request->file('curriculum'));
        }

        return $application;
    }
}
