<?php

namespace App\Models;

use EscapeWork\Manager\Models\Model;
use EscapeWork\LaraMedias\Traits\Medias;
use EscapeWork\LaraMedias\Contracts\Mediable;
use EscapeWork\LaravelSteroids\Sluggable;
use EscapeWork\LaravelSteroids\Presentable;
use EscapeWork\LaravelSteroids\SortableScope;
use EscapeWork\LaravelSteroids\Sortable;

class Award extends Model implements Mediable
{
    use Presentable, Sortable;

    /**
     * Table
     */
    protected $table = 'awards';

    /**
     * Fillable fields
     */
    protected $fillable = [
        'about_id',
        'description',
        'title',
        'segment',
        'category',
        'picture',
        'order'
    ];

    /**
     * The presenter class
     */
    protected $presenter = 'App\Presenters\AwardPresenter';

    /**
     * Use Medias
     */
    use Medias;

    public function medias()
    {
        return $this->morphMany('EscapeWork\LaraMedias\Models\Media', 'medias', 'media_model', 'model_id')
                    ->orderBy('order');
    }

    public static function boot()
    {
        parent::boot();
        static::addGlobalScope(new SortableScope('order'));
    }

    public function uploadBlob($picture, $field)
    {
        if ($picture) {

            $image = base64_decode(str_replace('data:image/jpeg;base64,','',$picture));
            $safeName = str_random(15).'.'.'jpg';
             \Storage::disk('local')->put('medias/'.$this->table.'/'.$safeName, $image);
             $this->$field = $safeName;
             $this->save();
        }
    }
}
