<?php

namespace App\Models;

use Carbon\Carbon;
use EscapeWork\LaraMedias\Traits\Medias;
use EscapeWork\LaravelSteroids\Cacheable;
use EscapeWork\Manager\Models\Model;
use EscapeWork\LaravelSteroids\Presentable;
use EscapeWork\LaravelSteroids\SortableScope;
use EscapeWork\LaravelSteroids\Sortable;
use App\Presenters\BannerPresenter;

class Banner extends Model
{
    use Presentable, Sortable, Cacheable, Medias;

    /**
     * Table
     */
    protected $table = 'banners';

    /**
     * Fillable fields
     */
    protected $fillable = [
        'type',
        'title',
        'subtitle',
        'description',
        'link',
        'active',
        'order',
        'button_text',
        'expire_at',
    ];

    /**
     * Dates
     */
    protected $dates = [
        'expire_at',
    ];

    /**
     * The presenter class
     */
    protected $presenter = BannerPresenter::class;

    /**
     * Caches
     */
    protected $cacheables = [
        'banners.actives',
    ];

    public function scopeActive($query)
    {
        return $query->where('active', '=', 1);
    }

    public function scopeNotExpired($query)
    {
        return $query->where(function($query) {
            $query->whereNull('expire_at')
                  ->orWhere('expire_at', '>=', Carbon::now()->format('Y-m-d'));
        });
    }

    public function setExpireAtAttribute($date)
    {
        $this->_setDateAttribute('expire_at', $date);
    }

    public function setLinkAttribute($value)
    {
        if (filter_var($value, FILTER_VALIDATE_URL)) {
            $this->attributes['link'] = $value;
        } else {
            $value = 'http://' .$value;

            if (filter_var($value, FILTER_VALIDATE_URL)) {
                $this->attributes['link'] = $value;
            }
        }
    }

    public function uploadBanner($banner)
    {
        if ($banner) {
            $this->uploadSingleMedia($banner, 'banner');
            $this->save();
        }
    }

    public function uploadBannerMobile($banner)
    {
        if ($banner) {
            $this->uploadSingleMedia($banner, 'banner_mobile');
            $this->save();
        }
    }

    public static function boot()
    {
        parent::boot();
        static::addGlobalScope(new SortableScope('order'));
    }

    public static function comboTypes($active, $options = [])
    {
        $options = array_merge(['sizes' => true, 'empty' => false], $options);
        $fields  = [];
        $types  = config('banners.types');

        if ($options['empty']) {
            $fields[''] = 'Tipo de banner';
        }

        foreach ($types as $type => $data) {
            $fields[$type] = $data['title'];

            if ($options['sizes']) {
                $fields[$type] .= ' ('.$data['width'].'px / '.$data['height'].'px)';
            }
        }

        return \Form::select('type', $fields, $active, ['class' => 'form-control']);
    }

    public function uploadBlob($picture, $field)
    {
        if ($picture) {

            $image = base64_decode(str_replace('data:image/jpeg;base64,','',$picture));
            $safeName = str_random(15).'.'.'jpg';
             \Storage::disk('local')->put('medias/'.$this->table.'/'.$safeName, $image);
             $this->$field = $safeName;
             $this->save();
        }
    }
}
