<?php

namespace App\Models;

use EscapeWork\LaravelSteroids\Model;
use EscapeWork\LaravelSteroids\Presentable;
use EscapeWork\LaravelSteroids\SortableScope;
use EscapeWork\LaravelSteroids\Sortable;

class Category extends Model
{

    /**
     * Table
     */
    protected $table = 'categories';

    /**
     * Fillable fields
     */
    protected $fillable = [
        'type',
        'show',
        'title',
        'subtitle',
        'extra_description',
        'description',
        'value',
        'billing_period',
        'active',
        'order'
    ];

    /**
     * Presentable
     */
    use Presentable;

    /**
     * Presentable
     */
    use Sortable;


    public static function boot()
    {
        parent::boot();
        static::addGlobalScope(new SortableScope('order'));
    }

    public function scopeActive($query)
    {
        return $query->where('active', '=', 1);
    }

    /**
     * The presenter class
     */
    protected $presenter = 'App\Presenters\CategoryPresenter';

    public function uploadBlob($picture, $field)
    {
        if ($picture) {

            $image = base64_decode(str_replace('data:image/jpeg;base64,','',$picture));
            $safeName = str_random(15).'.'.'jpg';
             \Storage::disk('local')->put('medias/'.$this->table.'/'.$safeName, $image);
             $this->$field = $safeName;
             $this->save();
        }
    }

    public function setValueAttribute($value){
      $value = str_replace(".","", $value);
      $this->attributes['value'] = str_replace(",",".", $value);
    }

    public function benefits(){
      return $this->hasMany('App\Models\Services\Benefit','model_id');
    }
}
