<?php

namespace App\Models;

use EscapeWork\LaravelSteroids\Model;
use EscapeWork\LaravelSteroids\Presentable;

class DID extends Model
{

    /**
     * Table
     */
    protected $table = 'dids';

    /**
     * Fillable fields
     */
    protected $fillable = [
        'type',
        'city',
        'area_code',
        'number',
        'available',
        'user_id',
        'order_id',
        'reserved',
        'reserved_until'
    ];

    protected $appends = ['label','text'];

    public function getLabelAttribute()
    {
      if($this->type == '0800')
      {
        return $this->number;
      }

      return "(".$this->area_code.") " . $this->number;
    }

    public function getTextAttribute()
    {

      if($this->type == '0800')
      {
        return $this->number;
      }
      
      return "(".$this->area_code.") " . $this->number;
    }

    use Presentable;

    public function scopeAvailable($query)
    {
        return $query->where('available', 1);
    }

    public function scopeSearch($query, $field, $value)
    {
      return $query->where($field, 'LIKE', '%' . $value . '%');
    }

    /**
     * The presenter class
     */
    protected $presenter = 'App\Presenters\DIDPresenter';

    public function user()
    {
      return $this->belongsTo('App\Models\User');
    }


}
