<?php

namespace App\Models;

use EscapeWork\LaravelSteroids\Model;
use EscapeWork\LaravelSteroids\Presentable;

class Download extends Model
{

    /**
     * Table
     */
    protected $table = 'downloads';

    /**
     * Fillable fields
     */
    protected $fillable = [
        'category_id',
        'title',
        'active',
    ];

    /**
     * Appends
     */
    protected $appends = ['full_path', 'created_at_formated'];

    /**
     * Presentable
     */
    use Presentable;

    /**
     * The presenter class
     */
    protected $presenter = 'App\Presenters\DownloadPresenter';

    public function category()
    {
        return $this->belongsTo('Protech\Models\DownloadCategory', 'category_id');
    }

    public function getFullPathAttribute()
    {
        return asset('files/downloads/' . $this->file);
    }

    public function getCreatedAtFormatedAttribute()
    {
        return $this->getAttribute('created_at')->format('d/m/Y');
    }

    public function scopeActive($query)
    {
        return $query->where('active', '=', 1);
    }
}
