<?php

namespace App\Models;

use EscapeWork\LaravelSteroids\Model;
use EscapeWork\LaravelSteroids\Presentable;
use App\Domains\Data\Datable;
use EscapeWork\LaravelSteroids\SortableScope;
use EscapeWork\LaravelSteroids\Sortable;

class Faq extends Model
{
    use Presentable, Datable, Sortable;

    /**
     * Table
     */
    protected $table = 'faqs';

    /**
     * Fillable fields
     */
    protected $fillable = [
        'model_id',
        'faq_model',
        'question',
        'answer',
        'active',
        'order'
    ];

    /**
     * The presenter class
     */
    protected $presenter = 'App\Presenters\FaqPresenter';

    public function subitems()
    {
        return $this->morphMany('App\Models\Faq', 'items', 'faq_model', 'model_id')
                    ->where('active',1)
                    ->orderBy('id','ASC');
    }

    public function scopeActive($query)
    {
        return $query->where('active', '=', 1);
    }

    public static function boot()
    {
        parent::boot();
        static::addGlobalScope(new SortableScope('order'));
    }
}
