<?php

namespace App\Models;

use App\Collections\InfoCollection;
use EscapeWork\LaravelSteroids\Model;
use EscapeWork\LaravelSteroids\Presentable;
use Illuminate\Support\Facades\Cache;
use EscapeWork\LaraMedias\Contracts\Mediable;
use EscapeWork\LaraMedias\Traits\Medias;

class Info extends Model
{

    /**
     * Table
     */
    protected $table = 'infos';

    /**
     * Fillable fields
     */
    protected $fillable = [
        'key',
        'type',
        'title',
        'value',
        'extra'
    ];

    /**
     * Without timestamps
     */
    public $timestamps = false;

    /**
     * Traits
     */
    use Presentable, Medias;

    /**
     * The presenter class
     */
    protected $presenter = 'App\Presenters\InfoPresenter';

    public function newCollection(array $models = array())
    {
        return new InfoCollection($models);
    }

    public static function boot()
    {
        static::saved(function($model) {
            Cache::forget('infos.all');
        });

        static::deleted(function($model) {
            Cache::forget('infos.all');
        });
    }

    public function uploadPicture($picture)
    {
        if ($picture) {
            $this->uploadSingleMedia($picture, 'value');
            $this->save();
        }
    }
}
