<?php

namespace App\Models;

use EscapeWork\LaravelSteroids\Model;
use EscapeWork\LaravelSteroids\Presentable;
use EscapeWork\LaravelSteroids\Sluggable;
use EscapeWork\LaraMedias\Traits\Medias;
use EscapeWork\LaravelSteroids\SortableScope;
use EscapeWork\LaravelSteroids\Sortable;

class Service extends Model
{

    /**
     * Table
     */
    protected $table = 'services';

    /**
     * Fillable fields
     */
    protected $fillable = [
        'title',
        'value',
        'value_ramal',
        'has_call_center',
        'has_cloud',
        'subtitle',
        'description',
        'active',
        'order',
        'free_dids'
    ];

    protected $appends = ['description_formatted','label','text'];

    /**
     * Sluggable
     */
    use Sluggable;

    /**
     * Presentable
     */
    use Presentable;

    /**
     * The presenter class
     */
    protected $presenter = 'App\Presenters\ServicePresenter';

    /**
     * Use medias
     */
    use Medias;

    /**
     * Use Sortable
     */
    use Sortable;

        public static function boot()
    {
        parent::boot();
        static::addGlobalScope(new SortableScope('order'));
    }

    public function scopeActive($query)
    {
        return $query->where('active', '=', 1);
    }

    public function uploadBlob($picture, $field)
    {
        if ($picture) {

            $image = base64_decode(str_replace('data:image/jpeg;base64,','',$picture));
            $safeName = str_random(15).'.'.'jpg';
            \Storage::disk('local')->put('medias/'.$this->table.'/'.$safeName, $image);
            $this->$field = $safeName;
            $this->save();
        }
    }

    public function getDescriptionFormattedAttribute()
    {
      return $this->present()->description;
    }

    public function getLabelAttribute()
    {
      return $this->title;
    }

    public function getTextAttribute()
    {
      return $this->title;
    }

    public function scopeSearch($query, $field, $value)
    {
      return $query->where($field, 'LIKE', '%' . $value . '%');
    }

     public function uploadIcon($icon)
    {
        if ($icon) {
            $this->uploadSingleMedia($icon, 'icon');
            $this->save();
        }
    }

    public function categories()
    {
        return $this->belongsToMany('App\Models\Category','service_categories','service_id','category_id');
    }

    public function benefits()
    {
        return $this->morphMany('App\Models\Services\Benefit', 'benefits', 'model', 'model_id')
                    ->where('active',1)
                    ->orderBy('order','ASC');
    }

    public function cases(){
      return $this->hasMany('App\Models\Cases','service_id');
    }

    public function faqs()
    {
        return $this->morphMany('App\Models\Faq', 'faqs', 'faq_model', 'model_id')
                    ->where('active',1)
                    ->orderBy('id','ASC');
    }

    public function setValueAttribute($value){
      $value = str_replace(".","", $value);
      $this->attributes['value'] = str_replace(",",".", $value);
    }
    public function setValueRamalAttribute($value){
      $value = str_replace(".","", $value);
      $this->attributes['value_ramal'] = str_replace(",",".", $value);
    }

}
