<?php

namespace App\Models\Services;

use EscapeWork\LaravelSteroids\Model;
use EscapeWork\LaravelSteroids\Presentable;
use EscapeWork\LaravelSteroids\SortableScope;
use EscapeWork\LaravelSteroids\Sortable;
use EscapeWork\LaraMedias\Traits\Medias;

class Benefit extends Model
{
    use Presentable, Sortable, Medias;

    /**
     * Table
     */
    protected $table = 'benefits';

    /**
     * Fillable fields
     */
    protected $fillable = [
        'model_id',
        'model',
        'value',
        'value_aditional',
        'value_extra',
        'title',
        'subtitle',
        'description',
        'picture',
        'active',
        'order',
        'description',
        'max'
    ];

    protected $appends = ['description_formatted'];

    /**
     * The presenter class
     */
    protected $presenter = 'App\Presenters\Services\BenefitPresenter';

    public static function boot()
    {
        parent::boot();
        static::addGlobalScope(new SortableScope('order'));
    }

    public function scopeActive($query)
    {
        return $query->where('active', '=', 1);
    }

    public function getDescriptionFormattedAttribute()
    {
      return $this->present()->description;
    }

    public function uploadPicture($picture)
    {
        if ($picture) {
            $this->uploadSingleMedia($picture, 'picture');
            $this->save();
        }
    }

    public function setValueAttribute($value){
      $value = str_replace(".","", $value);
      $this->attributes['value'] = str_replace(",",".", $value);
    }
    public function setValueAditionalAttribute($value){
      $value = str_replace(".","", $value);
      $this->attributes['value_aditional'] = str_replace(",",".", $value);
    }
}
