<?php

namespace App\Providers;

use Illuminate\Support\Facades\Route;
use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'App\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param  \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        //

        parent::boot();
    }

    /**
     * Define the routes for the application.
     *
     * @param  \Illuminate\Routing\Router  $router
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
        $this->mapManagerRoutes();
        // $this->mapApiRoutes();
        $this->mapWebhooksRoutes();
    }

    protected function mapWebRoutes()
    {
        Route::group([
            'middleware' => ['web'],
            'namespace'  => $this->namespace . '\App',
        ], function ($router) {
            require base_path('routes/web.php');
        });
    }

    protected function mapManagerRoutes()
    {
        Route::group([
            'prefix'     => config('manager.url'),
            'middleware' => ['web', 'manager.authenticated'],
            'as'         => 'manager.',
            'namespace'  => $this->namespace . '\Manager'
        ], function($router) {
            require base_path('routes/manager.php');
        });
    }

    /**
     * Define the "api" routes for the application.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace . '\Api',
            'prefix'     => 'api',
        ], function ($router) {
            require base_path('routes/api.php');
        });
    }

    public function mapWebhooksRoutes()
    {
        Route::namespace($this->namespace . '\Webhooks')
             ->prefix('webhooks')
             ->group(base_path('routes/webhooks.php'));
    }
}
