<?php

namespace App\Repositories;

use App\Models\DID;
use EscapeWork\LaravelSteroids\Repository;
use Carbon\Carbon;

class DIDRepository extends Repository
{

    public function __construct(DID $model)
    {
        $this->setModel($model);
    }

    public function create(array $data)
    {
        $this->model->fill($data);
        $this->model->save();

        return $this->model;
    }

    public function update($id, array $data)
    {
        $this->model = $this->model->findOrFail($id);
        $this->model->fill($data);
        $this->model->save();

        return $this->model;
    }

    public function destroy($id)
    {
        $this->model = $this->model->findOrFail($id);
        $this->model->delete();

        return $this->model;
    }

    public function manager($request)
    {
        $query = $this->model->newQuery();

        if ($request->get('area_code')) {
            $query->search('area_code', $request->area_code);
        }

        if ($request->get('number')) {
            $query->search('number', $request->number);
        }

        if ($request->get('type')) {
            $query->where('type', $request->type);
        }

        return $query->paginate();
    }

    public function cities()
    {
        $query = $this->model->newQuery();
        $query->select(\DB::raw("id, TRIM(REPLACE(city,UNHEX('C2A0'),'') ) AS city"));
        $query->where('available', 1);
        $query->where('reserved', null);
        $query->whereNotNull('city');
        $query->groupBy('city');
        $query->orderBy('city','ASC');
        $query->distinct();
        $result = $query->get();

        $list = [];
        foreach($result as $did)
        {

          // get city numbers
          $query = $this->model->newQuery();
          $query->where('available', 1);
          $query->where('reserved', null);
          $query->where('city', $did->city);
          $dids = $query->get();

          $list[] = (object) ['id' => $did->city, 'title' => $did->city, 'numbers' => $dids];
        }

        return $list;
    }

    public function numbers_0800()
    {
      $query = $this->model->newQuery();
      $query->where('available', 1);
      $query->where('reserved', null);
      $query->whereIn('type', ['0800','800'] );
      $dids = $query->get();

      return $dids;
    }

    public function findNext($type, $area_code = null, $city = null)
    {
        $query = $this->model->newQuery();
        $query->where('reserved', session('checkoutKey'));

        if($type == 'roc')
        {
          $query->whereIn('type', ['pop','roc']);
        }

        if($type == '0800')
        {
          $query->whereIn('type', ['0800','800'] );
        }

        $query->where('available', 1);

        if ($area_code != null) {
            $query->where('area_code', $area_code);
        }

        if ($city != null) {
            $query->where('city', $city);
        }

        return $query->first();
    }

    public function findOrFailBySlug($slug)
    {
        if (! $category = $this->model->where('slug', '=', $slug)->first()) {
            abort(404);
        }

        return $category;
    }

    public function actives()
    {
        return $this->model
                    ->active()
                    ->get();
    }

    public function removeReserved($checkoutKey)
    {
      $query = $this->model->newQuery();
      $query->where('reserved', $checkoutKey);
      $query->update(['reserved' => null, 'reserved_until' => null]);

    }

    public function releaseUnused()
    {
      $query = $this->model->newQuery();
      $query->where('reserved_until', '<=', Carbon::now()->format('Y-m-d H:i:s'));
      $query->update(['reserved' => null, 'reserved_until' => null]);

    }

    public function release($number)
    {
      $query = $this->model->newQuery();
      $query = $this->where('id', $number);
      $query->update(['reserved' => null, 'reserved_until' => null]);

    }

    public function releaseMultiple($numbers)
    {
      foreach($numbers as $number)
      {
        $query = $this->model->newQuery();
        $query = $this->where('id', $number['number']['id']);
        $query->update(['reserved' => null, 'reserved_until' => null]);
      }

    }

    public function reserve($number, $checkoutKey)
    {
      $query = $this->model->newQuery();
      $query->where('id', $number);
      $query->where('reserved', null);
      $number = $query->first();

      if($number)
      {
        $number->reserved = $checkoutKey;
        $number->reserved_until = Carbon::now()->addMinutes(60)->format('Y-m-d H:i:s');
        $number->save();

        return true;
      }

      return false;

    }
}
