<?php

namespace App\Repositories;

use App\Models\Download;
use EscapeWork\LaravelUploader\Upload;
use EscapeWork\LaravelSteroids\Repository;

class DownloadRepository extends Repository
{

    public function __construct(Download $download)
    {
        $this->setModel($download);
    }

    public function create(array $data)
    {
        $this->model->fill($data);
        $this->model->save();

        return $this->model;
    }

    public function update($id, array $data)
    {
        $this->model = $this->model->findOrFail($id);
        $this->model->fill($data);
        $this->model->save();

        return $this->model;
    }

    public function destroy($id)
    {
        $this->model = $this->model->findOrFail($id);

        if (is_file($this->model->present->file)) {
            unlink($this->model->present->file);
        }

        $this->model->delete();

        return $this->model;
    }

    public function uploadFile($file)
    {
        if ($file) {
            $uploader = app('EscapeWork\LaravelSteroids\Upload');
            $filename = $uploader->to(public_path() . '/files/downloads')
                                 ->execute($file);

            $this->model->file = $filename;
            $this->model->save();
        }
    }

    public function manager($request)
    {
        $query = $this->model->newQuery();

        if ($request->has('title')) {
            $query->search('title', $request->title);
        }

        if ($request->has('category_id')) {
            $query->where('category_id', '=', $request->category_id);
        }

        return $query->orderBy('created_at', 'desc')
                     ->paginate();
    }

    public function search()
    {
        return $this->model
                    ->orderBy('created_at', 'desc')
                    ->paginate();
    }

    public function byCategory($categoryId)
    {
        return $this->model
                    ->where('category_id', '=', $categoryId)
                    ->active()
                    ->orderBy('created_at', 'desc')
                    ->get();
    }

    public function all()
    {
        return $this->model
                    ->active()
                    ->orderBy('created_at', 'desc')
                    ->get();
    }
}
