<?php

namespace App\Repositories;

use App\Models\News;
use EscapeWork\LaravelSteroids\Repository;
use Illuminate\Support\Facades\Cache;

class NewsRepository extends Repository
{

    public function __construct(News $news)
    {
        $this->setModel($news);
    }

    public function create(array $data)
    {
        $this->model->fill($data);
        $this->model->save();

        return $this->model;
    }

    public function update($id, array $data)
    {
        $this->model = $this->model->findOrFail($id);
        $this->model->fill($data);
        $this->model->save();

        return $this->model;
    }

    public function destroy($id)
    {
        $this->model = $this->model->findOrFail($id);
        $this->model->delete();

        return $this->model;
    }

    public function manager($request)
    {
        $query = $this->model->newQuery();

        if ($request->has('title')) {
            $query->search('title', $request->title);
        }

        if ($request->get('news_category_id') != null) {
            $query->where('news_category_id', $request->news_category_id);
        }

        return $query->paginate();
    }

    public function search($request, $category = null)
    {
        $query = $this->model->newQuery();

        if ($request->has('title')) {
            $query->search('title', $request->title);
        }

        if($category != null)
        {
          $query->where('news_category_id', $category->id);
        }

        $query->active();
        $query->published();

        return $query->paginate(6);
    }

    public function related($news)
    {
        $query = $this->model->newQuery();

        if($news->category){
            $query->where('news_category_id', $news->category->id);
        }

        $query->where('id', '!=', $news->id);
        $query->active();
        $query->published();
        $query->inRandomOrder();
        $query->take(6);

        return $query->get();
    }

    public function latest($take = 3)
    {
        return $this->model
                    ->active()
                    ->take(6)
                    ->published()
                    ->get();
    }
}
