<?php

namespace App\Repositories;

use App\Models\Service;
use EscapeWork\LaravelSteroids\Repository;

class ServiceRepository extends Repository
{

    public function __construct(Service $model)
    {
        $this->setModel($model);
    }

    public function create(array $data)
    {
        $this->model->fill($data);
        $this->model->save();

        return $this->model;
    }

    public function update($id, array $data)
    {
        $this->model = $this->model->findOrFail($id);
        $this->model->fill($data);
        $this->model->save();

        return $this->model;
    }

    public function destroy($id)
    {
        $this->model = $this->model->findOrFail($id);
        $this->model->delete();

        return $this->model;
    }

    public function uploadPicture($picture)
    {
        if ($picture) {
            $this->model->storeSingleMedia($picture, 'services', 'picture');
            $this->model->save();
        }
    }

    public function manager($request)
    {
        $query = $this->model->newQuery();

        if ($request->has('title')) {
            $query->search('title', $request->title);
        }

        return $query->paginate();
    }

    public function findOrFailBySlug($slug)
    {
        if (! $news = $this->model->where('slug', '=', $slug)->first()) {
            abort(404);
        }

        return $news;
    }

    public function others($solution)
    {

        $query = $this->model->newQuery();
        $query->where('id','!=', $solution->id);

        return $query->active()
                    ->get();
    }

    public function actives()
    {
        return $this->model
                    ->with('benefits')
                    ->active()
                    ->get();
    }

    public function firstActive()
    {
        return $this->model
                    ->active()
                    ->first();
    }
}
