<?php

namespace App\Services;

use App\Models\Product;
use App\Models\Subscriber;
use DrewM\MailChimp\MailChimp;

class MailChimpService
{
    /**
     * @var DrewM\MailChimp\MailChimp
     */
    protected $client;

    public function __construct()
    {
        $this->client = new MailChimp(config('services.mailchimp.api_key'));
    }

    public function export(Subscriber $subscriber)
    {
        // se quiser ver os grupos de interesse
        // dd($this->client->get('lists/'.config('services.mailchimp.list_id').'/interest-categories/d3c35917bb/interests'));

        # verificando se o usuário já existe
        $hash   = md5(strtolower($subscriber->email));
        $exists = (object) $this->client->get('lists/'.config('services.mailchimp.list_id').'/members/' . $hash);
        $data   = [
            'email_address' => $subscriber->email,
            'merge_fields'  => ['FNAME' => $subscriber->name],
            'status'        => 'subscribed',
            // 'interests'     => [
            //     'id-do-group' => true // Vínculo -> Site
            // ],
        ];

        if ($exists->status == 404) {
            # não existe, criando
            $result = $this->client->post('lists/'.config('services.mailchimp.list_id').'/members', $data);
        } else {
            # já existe, atualizando
            $result = $this->client->put('lists/'.config('services.mailchimp.list_id').'/members/' . $hash, $data);
        }

        return $result;
    }

    public function __call($method, $parameters)
    {
        return call_user_func_array([$this->client, $method], $parameters);
    }
}
