// -------------------------------------------------------------------------
// requires
require('./bootstrap');
import Swiper from 'swiper/bundle';

(function() {
	window.App = window.App || {};

	// Menu sidebar
	App.MenuResponsive = {
		init: function() {
			this.fetchElements();
			this.bindUIEvents();
		},

		fetchElements: function() {
			this.$body    = $('body');
			this.$menu    = $('#menu-sidebar');
			this.$btnOpen = $('.js-btn-menu-responsive');
		},

		bindUIEvents: function() {
			var _this = this;

			this.$btnOpen.on('click', function() {
				_this.toggle();

				if (_this.$btnOpen.hasClass('active')) {
					_this.listenToCloseEvent();
				}
			});
		},

		toggle: function() {
			this.$btnOpen.toggleClass('active');
			this.$body.toggleClass('cbp-spmenu-push-toright');
			this.$menu.toggleClass('cbp-spmenu-open');
		},

		listenToCloseEvent: function() {
			var _this = this;

			window.setTimeout(function() {
				_this.$body.on('click.menu', function(e) {
					if ($(e.target).closest('.cbp-spmenu').length === 0 && $(e.target).closest('.js-btn-menu-responsive').length === 0) {
						_this.toggle();
						_this.$body.off('click.menu');
					}
				});
			}, 50);
		}
	};

	// Page Scroll
	App.PageScroll = function() {
		return {
			init: function(){
				// scroll page
				$(document).on("scroll", onScroll);

				var difference = 90;

				$('.btn-anchor').on('click', function (e) {
					e.preventDefault();

					$('body').removeClass('cbp-spmenu-push-toright');
					$('#menu-sidebar').removeClass('cbp-spmenu-open');
					$('.btn-menu').removeClass('active');

					var target = this.hash,
						target = $(target);

					if($('body').hasClass('modal-open')){
						$('.modal').modal('hide');
					}

					setTimeout(function() {
						$('html, body').stop().animate({
							'scrollTop': target.offset().top - difference
						}, 800, 'swing');
					}, 500);
				});

				if(window.location.hash) {
					$('body').removeClass('cbp-spmenu-push-toright');
					$('#menu-sidebar').removeClass('cbp-spmenu-open');
					$('.btn-menu').removeClass('active');

					var hash = window.location.hash.substr(0);

					$('html, body').stop().animate({
						'scrollTop': $(hash).offset().top - difference
					}, 800, 'swing', function(){
						history.pushState("", document.title, window.location.pathname);
					});
				}
			}
		};
	}();

	function onScroll(event){
		var scrollPos = $(document).scrollTop(),
			header    = $('.header'),
			content   = $('.content'),
			logo      = header.find('.logo-main'),
			btnCta    = header.find('.btn-cta');

		if (scrollPos >= 1 ) {
			header.addClass("sticky");
			content.addClass("sticky");

			if (logo.hasClass("logo-main-home")) {
				logo.attr('src', 'assets/images/logos/i360-tenologia-logo.png');
			}

			if (btnCta.hasClass("btn-white btn-cta-home")) {
				btnCta.removeClass("btn-white").addClass("btn-primary");
			}
		} else {
			header.removeClass("sticky");
			content.removeClass("sticky");

			if (logo.hasClass("logo-main-home")) {
				logo.attr('src', 'assets/images/logos/i360-tenologia-logo-2.png');
			}

			if (btnCta.hasClass("btn-cta-home")) {
				btnCta.removeClass("btn-primary").addClass("btn-white");
			}
		}
	}

	// Swiper Integrations
	App.SwiperIntegrations = function() {
		return {
			init: function(){
				var swiper = new Swiper ('.swiper-integrations', {
					loop: false,
					speed: 800,
					slidesPerView: 2,
					spaceBetween: 30,
					autoHeight: true,
					preventClicks: false,
					preventClicksPropagation: false,
					navigation: {
						nextEl: '.swiper-integrations-next',
						prevEl: '.swiper-integrations-prev',
					},
					pagination: {
						el: ".integrations-pagination",
						clickable: true
					},
					breakpoints: {
						480: {
							slidesPerView: 3,
						},
						768: {
							slidesPerView: 4,
						},
						992: {
							slidesPerView: 4,
						},
						1024: {
							slidesPerView: 3,
						},
						1100: {
							slidesPerView: 4,
						},
						1200: {
							slidesPerView: 5
						}
					}
				});
			}
		};
	}();

	// Swiper Plans
	App.SwiperPlans = function() {
		return {
			init: function(){
				var swiper = new Swiper ('.swiper-plans', {
					loop: false,
					speed: 800,
					slidesPerView: 1,
					spaceBetween: 20,
					autoHeight: true,
					preventClicks: false,
					preventClicksPropagation: false,
					navigation: {
						nextEl: '.swiper-plans-next',
						prevEl: '.swiper-plans-prev',
					},
					pagination: {
						el: ".plans-pagination",
						clickable: true
					},
					breakpoints: {
						480: {
							slidesPerView: 2,
						},
						768: {
							slidesPerView: 3,
						},
						992: {
							slidesPerView: 3,
						}
					}
				});
			}
		};
	}();

	// Swiper Gallery
	App.SwiperGallery = function() {
		return {
			init: function(){
				var swiper = new Swiper ('.swiper-gallery', {
					loop: true,
					effect: 'fade',
					lazy: true,
					speed: 800,
					observer: true,
					observeParents: true,
					autoplay: {
						delay: 5000,
					},
					navigation: {
						nextEl: '.swiper-gallery-next',
						prevEl: '.swiper-gallery-prev',
					},
					pagination: {
						el: '.gallery-pagination',
						clickable: true
					}
				});
			}
		};
	}();

	// Swiper Trends
	App.SwiperTrends = function() {
		return {
			init: function(){
				var swiper = new Swiper ('.swiper-trends', {
					loop: false,
					speed: 800,
					slidesPerView: 1,
					spaceBetween: 30,
					autoHeight: true,
					preventClicks: false,
					preventClicksPropagation: false,
					navigation: {
						nextEl: '.swiper-trends-next',
						prevEl: '.swiper-trends-prev',
					},
					pagination: {
						el: ".trends-pagination",
						clickable: true
					},
					breakpoints: {
						480: {
							slidesPerView: 2,
						},
						768: {
							slidesPerView: 3,
						},
						992: {
							slidesPerView: 3,
						},
						1024: {
							slidesPerView: 4,
							spaceBetween: 30,
						},
						1200: {
							slidesPerView: 4,
							spaceBetween: 60
						}
					}
				});
			}
		};
	}();

	App.PanelContact = function () {
		return {
			init: function init() {
				var panel = $('.panel-contact'),
					panelHeight = panel.height() + 400,
					posTop = $('.header').height(),
					posiLimit = $('.footer').offset().top - panelHeight;

				$(window).on("scroll", function () {
					var scroll = $(window).scrollTop();

					if (scroll > 1) {
						panel.addClass('hide-block');
					}

					if (scroll > posiLimit) {
						panel.addClass('hide-custom');
					} else {
						panel.removeClass('hide-custom');
					}
				});

				setTimeout(function() {
					if (!panel.hasClass('hide-block')) {
						panel.addClass('hide-block');
					}
				}, 4000);

				$(window).scroll(function() {
					clearTimeout($.data( this, "scrollCheck"));
					panel.addClass('hide-custom');
					$.data( this, "scrollCheck", setTimeout(function() {
						panel.removeClass('hide-custom');
					}, 500) );
				});
			}
		};
	}();

	//init
	App.MenuResponsive.init();
	App.PageScroll.init();
	App.SwiperGallery.init();
	App.SwiperIntegrations.init();
	App.SwiperPlans.init();
	App.SwiperTrends.init();
	App.PanelContact.init();

	// help
	$('[data-phone]').inputmask({ mask: '(99) 9{4,5}.9999', showMaskOnHover: false });
	$('[data-cpf]').inputmask({ mask: '999.999.999-99', showMaskOnHover: false });
	$('[data-cnpj]').inputmask({ mask: '99.999.999/9999-99', showMaskOnHover: false });

	// forms
	App.FormContact = new App.Contact('.js-form-contact', {
		conversionCategory: 'Contato',
		conversionAction: 'Enviado'
	}, function() {
		//updateRecaptchaToken();
	});

	App.FormNews = new App.Contact('.js-form-subscriber', {
		conversionCategory: 'Cadastro',
		conversionAction: 'Newsletter'
	}, function() {
		//updateRecaptchaToken();
	});

	App.FormAffiliate = new App.Contact('.js-form-affiliate', {
		conversionCategory: 'Contato',
		conversionAction: 'Enviado'
	}, function() {
		//updateRecaptchaToken();
		$('#modal-affiliates').modal('hide');
	});

	App.FormPartner = new App.Contact('.js-form-partner', {
		conversionCategory: 'Contato',
		conversionAction: 'Enviado'
	}, function() {
		//updateRecaptchaToken();
		$('#modal-partner').modal('hide');
	});

	App.FormChange = new App.Contact('.js-form-change', {
		conversionCategory: 'Contato',
		conversionAction: 'Enviado'
	}, function() {
		//updateRecaptchaToken();
		$('#modal-change-plan').modal('hide');
	});

	App.FormCancel = new App.Contact('.js-form-cancel', {
		conversionCategory: 'Contato',
		conversionAction: 'Enviado'
	}, function() {
		//updateRecaptchaToken();
		$('#modal-cancel-plan').modal('hide');
	});

	$(".custom-scroll").mCustomScrollbar({
		theme: "dark-3",
		//setLeft: -100,
		alwaysShowScrollbar: 1,
		scrollButtons: "disable",
		live: true,
		advanced: {
			updateOnContentResize: true,
			updateOnBrowserResize: true,
		}
	});
})();
