@extends('app.master')

@section('seo')
	@include('app.inc.seo', [
		'title'       =>  $news->title,
		'description' =>  $news->subtitle,
		'route'       => route('trends.show', $news->slug),
	])
@stop

@section('styles')
	@parent
	<link rel="stylesheet" type="text/css" href="{{ Asset::v('assets/css/sections/trends.css') }}">
@stop

@section('content')
	<div class="content-breadcrumb d-none d-lg-block">
		<div class="container">
			<nav aria-label="breadcrumb">
				<ul class="breadcrumb custom">
					<li class="breadcrumb-item">
						<a href="{{ route('home') }}" class="breadcrumb-link" title="Home">Home</a>
					</li>
					<li class="breadcrumb-item">
						<a href="{{ route('trends.index') }}" class="breadcrumb-link" title="Trends">Trends</a>
					</li>
					<li class="breadcrumb-item active" aria-current="page">{{ $news->title }}</li>
				</ul>
				{{-- /breadcrumb --}}
			</nav>
		</div>
		{{-- /container --}}
	</div>
	{{-- /content-breadcrumb --}}

	<section class="section section-trend section-pages text-center">
		<div class="container">
			<div class="section-content">
				<h2 class="section-title">{{ $news->title }}</h2>

				<div class="trend-infos">
					<span class="date">{{ $news->present->date }}</span> - <span class="category"></span>{{ $news->category->title }}</a>
				</div>
				{{-- /trend-infos --}}

				@if($news->picture)
				<img src="{{ $news->present->picture(800,'auto','auto') }}" alt="{{ $news->title }}">
				@endif

				<div class="section-description">
					{!! $news->content !!}
				</div>
				{{-- /section-description --}}

				<ul class="share mt-5 text-center">
					<li class="share-item">Compartilhe:</li>

					<li class="share-item">
						<a href="http://www.facebook.com/sharer.php?u={{ route('trends.show', $news->slug) }}&picture={{ $news->present->picture(800,600,'crop') }}" class="share-item-link" title="Compartilhar no Facebook" target="_blank" data-original-title="Compartilhar no Facebook">
							<span class="table">
								<span class="centraliza">
									<i class="icon fab fa-facebook-f"></i>
								</span>
								{{-- /centraliza --}}
							</span>
							{{-- /table --}}
						</a>
					</li>

					<li class="share-item">
						<a href="http://twitter.com/home?status={{ route('trends.show', $news->slug) }}" class="share-item-link" title="Compartilhar no Twitter" target="_blank" data-original-title="Compartilhar no Twitter">
							<span class="table">
								<span class="centraliza">
									<i class="icon fab fa-twitter"></i>
								</span>
								{{-- /centraliza --}}
							</span>
							{{-- /table --}}
						</a>
					</li>

					<li class="share-item">
						<a href="https://www.linkedin.com/sharing/share-offsite/?url={{ route('trends.show', $news->slug) }}&title={{ $news->title }}&summary={{ $news->present->excerpt(500) }}&source={{ route('home') }}" class="share-item-link" title="Compartilhar no LinkedIn" target="_blank" data-original-title="Compartilhar no LinkedIn">
							<span class="table">
								<span class="centraliza">
									<i class="icon fab fa-linkedin-in"></i>
								</span>
								{{-- /centraliza --}}
							</span>
							{{-- /table --}}
						</a>
					</li>

					<li class="share-item">
						<a href="https://api.whatsapp.com/send?text=Leia a Notícia '{{ $news->title }} - {{ route('trends.show', $news->slug) }}" class="share-item-link" data-toggle="tooltip" data-placement="top" title="Compartilhar no WhatsApp" target="_blank" data-original-title="Compartilhar no WhatsApp">
							<span class="table">
								<span class="centraliza">
									<i class="icon fab fa-whatsapp"></i>
								</span>
								{{-- /centraliza --}}
							</span>
							{{-- /table --}}
						</a>
					</li>

					<li class="share-item">
						<a href="mailto:?subject=Veja esse artigo&amp;body=Confira esse trend - {{ route('trends.show', $news->slug) }} {{ $news->title }}" class="share-item-link" title="Compartilhar no E-mail" target="_blank" data-original-title="Compartilhar no E-mail">
							<span class="table">
								<span class="centraliza">
									<i class="icon fal fa-envelope"></i>
								</span>
								{{-- /centraliza --}}
							</span>
							{{-- /table --}}
						</a>
					</li>

					<li class="share-item">
						<a href="javascript:window.print()" class="share-item-link" title="Imprimir" data-original-title="Imprimir">
							<span class="table">
								<span class="centraliza">
									<i class="icon fal fa-print"></i>
								</span>
								{{-- /centraliza --}}
							</span>
							{{-- /table --}}
						</a>
					</li>
				</ul>
				{{-- /share --}}
			</div>
			{{-- /section-content --}}
		</div>
		{{-- /container --}}
	</section>
	{{-- /section --}}

	@if($related->count()>0)
	<section class="section section-trends section-trends-related text-center">
		<div class="container">
			<h3 class="section-title white">Trends relacionados</h3>

			<div class="row row-blocks">
				@foreach($related as $news)
				<div class="col-6 col-sm-4 col-lg-3 col-blocks">
					@include('app.trends.snippet')
					{{-- /block-trend --}}
				</div>
				{{-- /col --}}
				@endforeach
			</div>
			{{-- /row --}}

			<div class="text-center mt-5 pt-3">
				<a href="{{ route('trends.index') }}" class="btn btn-primary" title="Veja mais trends">Veja mais trends</a>
			</div>
			{{-- /help-class --}}
		</div>
		{{-- /container --}}
	</section>
	{{-- /trends --}}
	@endif

	@include('app.modules.section-newsletter')
	{{-- /section --}}

	@include('app.modules.section-contact')
	{{-- /section --}}
@stop
