@extends(config('manager.views.layouts.master'))

@section('content')
    @include('manager::partials.breadcrumb', [
        'pages' => ['DIDs']
    ])

    <div class="page-header clearfix">
        <h2 class="pull-left">DIDs</h2>

        <div class="pull-right" style="margin-top: 10px;">
            <a href="{{ route('manager.dids.create') }}" class="btn btn-primary">Inserir Único</a>
            <a href="{{ route('manager.dids.import') }}" class="btn btn-primary">Importar XLS</a>
        </div><!-- .pull-right -->
    </div><!-- .page-header -->

    @include('manager::partials.messages')

    <form action="{{ route('manager.dids.index') }}" class="form-inline well">
        <input type="text" name="area_code" class="form-control" value="{{ request('area_code') }}" placeholder="Busca por DDD..." maxlength="255" autofocus>
        <input type="text" name="number" class="form-control" value="{{ request('number') }}" placeholder="Busca por número..." maxlength="255">

        <select class="form-control" name="type">
          <option value="">Todos os números</option>
          @foreach(config('app.phone_types') as $type)
          <option @if(request()->get('type') == $type) selected @endif value="{{ $type }}">{{ strtoupper($type) }}</option>
          @endforeach
        </select>

        <button type="submit" class="btn btn-primary">Filtrar</button>
        <a href="{{ route('manager.dids.index') }}" class="btn btn-default">Limpar filtros</a>
    </form>

    <table class="table table-bordered table-striped table-hover">
        <thead>
            <tr>
                <th>Tipo</th>
                <th>Cidade</th>
                <th>Número</th>
                <th width="100">Reservado</th>
                <th width="100">Utilizado</th>
                <th width="300">Utilizado por</th>
                <th width="150">Ações</th>
            </tr>
        </thead>
        <tbody>
            @foreach ($dids as $did)
                <tr data-id="{{ $did->id }}" data-manager-sortable-url="{{ route('manager.dids.updateBasic', $did->id) }}">
                    <td>{{ $did->present->type }}</td>
                    <td>{{ $did->city ? $did->city : 'NA' }}</td>
                    <td>{{ $did->area_code }} {{ $did->number }}</td>
                    <td>{{ $did->reserved != null ? 'Sim' : 'Não' }}</td>
                    <td>{{ $did->available == 1 ? 'Não' : 'Sim' }}</td>
                    <td>{{ $did->present->user }}</td>
                    <td>
                        <div class="btn-group btn-group-sm">

                            @if($did->available == 1)
                            <a href="{{ route('manager.dids.edit', $did->id) }}" class="btn btn-default" title="Editar">
                                <span class="glyphicon glyphicon-trash"></span> editar
                            </a>
                            @else
                            <a href="javascript: void(0);" class="btn btn-default btn-disabled disabled" title="Editar">
                                <span class="glyphicon glyphicon-trash"></span> editar
                            </a>
                            @endif

                            @if($did->reserved == null)
                            <a href="{{ route('manager.dids.destroy', $did->id) }}" class="btn btn-default" data-delete="true" title="Excluir">
                                <span class="glyphicon glyphicon-trash"></span> excluir
                            </a>
                            @endif
                        </div><!-- .btn-group -->
                    </td>
                </tr>
            @endforeach
        </tbody>
    </table><!-- .table -->

    @if ($dids->count() === 0)
        <h3 class="text-center">Nenhum registro encontrado.</h3>
    @endif

    {!! $dids->appends(request()->except('page'))->render() !!}
@stop
