@extends(config('manager.views.layouts.master'))

@section('content')
    @include('manager::partials.breadcrumb', [
        'pages' => ['Downloads']
    ])

    @include('manager::partials.page-header', [
        'title' => 'Downloads',
        'link'  => [
            'route'    => route('manager.downloads.create'),
            'label'    => 'Inserir novo download',
            'btn-type' => 'primary'
        ],
    ])

    @include('manager::partials.messages')

    <form action="{{ route('manager.downloads.index') }}" class="form-inline well">
        @if ($categories->count() > 0)
            {!! Form::select('category_id', $categories->combobox(['empty_option_label' => 'Categoria...']), request('category_id'), ['class' => 'form-control']) !!}
        @endif

        <input type="text" name="title" class="form-control" value="{{ request('title') }}" maxlength="255" placeholder="Nome do download..." autofocus>

        <button type="submit" class="btn btn-primary">Filtrar</button>
        <a href="{{ route('manager.downloads.index') }}" class="btn btn-default">Limpar filtros</a>
    </form>

    <table class="table table-bordered table-striped table-hover">
        <thead>
            <tr>
                <th width="40">#</th>
                <th>Download</th>
                <th width="100">Ativo</th>
                <th width="225">Ações</th>
            </tr>
        </thead>
        <tbody>
            @foreach ($downloads as $download)
                <tr>
                    <td>{{ $download->id }}</td>
                    <td>{{ $download->title }}</td>
                    <td><input type="checkbox" data-id="{{ $download->id }}" data-manager-update-checkbox="active" data-manager-update-url="{{ route('manager.downloads.updateBasic', $download->id) }}" {{ $download->active ? 'checked="checked"' : null }}></td>
                    <td>
                        <div class="btn-group btn-group-sm">
                            <a href="{{ $download->present->file }}" class="btn btn-default" title="Download" download="{{ $download->file }}">
                                <span class="glyphicon glyphicon-download"></span> download
                            </a>

                            <a href="{{ route('manager.downloads.edit', $download->id) }}" class="btn btn-default" title="Editar">
                                <span class="glyphicon glyphicon-pencil"></span> editar
                            </a>

                            <a href="{{ route('manager.downloads.destroy', $download->id) }}" class="btn btn-default" data-delete="true" title="Excluir">
                                <span class="glyphicon glyphicon-trash"></span> excluir
                            </a>
                        </div><!-- .btn-group -->
                    </td>
                </tr>
            @endforeach
        </tbody>
    </table><!-- .table -->

    {!! $downloads->appends(request()->except('page'))->render() !!}
@stop
