@extends(config('manager.views.layouts.master'))

@section('content')
    @include('manager::partials.breadcrumb', [
        'pages' => ['Regiões']
    ])

    @include('manager::partials.page-header', [
        'title' => 'Regiões',
        'link'  => [
            'route'    => route('manager.sections.create'),
            'label'    => 'Inserir nova seção',
            'btn-type' => 'primary',
        ],
    ])

    @include('manager::partials.messages')

    <form action="{{ route('manager.sections.index') }}" class="form-inline well">
        <input type="text" name="title" class="form-control" value="{{ request('title') }}" placeholder="Busca por nome da região..." maxlength="255" autofocus>

        <button type="submit" class="btn btn-primary">Filtrar</button>
        <a href="{{ route('manager.sections.index') }}" class="btn btn-default">Limpar filtros</a>
    </form>

    <table class="table table-bordered table-striped table-hover">
        <thead>
            <tr>
                <th>Título</th>
                <th width="100">Ativo</th>
                <th width="150">Ações</th>
            </tr>
        </thead>
        <tbody>
            @foreach ($sections as $section)
                <tr>
                    <td>{{ $section->title }}</td>
                    <td><input type="checkbox" data-id="{{ $section->id }}" data-manager-update-checkbox="active" data-manager-update-url="{{ route('manager.sections.updateBasic', $section->id) }}" {{ $section->active ? 'checked="checked"' : null }}></td>
                    <td>
                        <div class="btn-group btn-group-sm">
                            <a href="{{ route('manager.sections.edit', $section->id) }}" class="btn btn-default" title="Editar">
                                <span class="glyphicon glyphicon-pencil"></span> editar
                            </a>

                            <a href="{{ route('manager.sections.destroy', $section->id) }}" class="btn btn-default" data-delete="true" title="Excluir">
                                <span class="glyphicon glyphicon-trash"></span> excluir
                            </a>

                        </div><!-- .btn-group -->
                    </td>
                </tr>
            @endforeach
        </tbody>
    </table><!-- .table -->

    @if ($sections->count() === 0)
        <h3 class="text-center">Nenhuma região encontrada.</h3>
    @endif

    {!! $sections->appends(request()->except('page'))->render() !!}
@stop
