@extends(config('manager.views.layouts.master'))

@section('content')
    @include('manager::partials.breadcrumb', [
        'pages' => ['Planos']
    ])

    @include('manager::partials.page-header', [
        'title' => 'Planos',
        'link'  => [
            'route'    => route('manager.services.create'),
            'label'    => 'Inserir Novo',
            'btn-type' => 'primary',
        ],
    ])

    @include('manager::partials.messages')

    <form action="{{ route('manager.services.index') }}" class="form-inline well">
        <input type="text" name="title" class="form-control" value="{{ request('title') }}" placeholder="Busca por nome..." maxlength="255" autofocus>

        <button type="submit" class="btn btn-primary">Filtrar</button>
        <a href="{{ route('manager.services.index') }}" class="btn btn-default">Limpar filtros</a>
    </form>

    <table class="table table-bordered table-striped table-hover">
        <thead>
            <tr>
                <th width="40"></th>
                <th>Título</th>
                <th width="100">Ativo</th>
                <th width="150">Ações</th>
            </tr>
        </thead>
        <tbody data-manager-sortable>
            @foreach ($services as $service)
                <tr data-id="{{ $service->id }}" data-manager-sortable-url="{{ route('manager.services.updateBasic', $service->id) }}">
                    <td style="text-align: center; cursor: move; vertical-align: middle;" title="Arraste para alterar a ordem"><i class="fa fa-arrows"></i></td>
                    <td>{{ $service->title }}</td>
                    <td><input type="checkbox" data-id="{{ $service->id }}" data-manager-update-checkbox="active" data-manager-update-url="{{ route('manager.services.updateBasic', $service->id) }}" {{ $service->active ? 'checked="checked"' : null }}></td>
                    <td>
                        <div class="btn-group btn-group-sm">

                            <a href="{{ route('manager.services.benefits.index', $service->id) }}" class="btn btn-default" title="Itens">
                                <span class="glyphicon glyphicon-camera"></span> itens
                            </a>

                             <a href="{{ route('manager.faqs.services.index', $service->id) }}" class="btn btn-default" title="Dúvidas" hidden>
                                <span class="glyphicon glyphicon-camera"></span> dúvidas
                            </a>

                            <a href="{{ route('manager.services.edit', $service->id) }}" class="btn btn-default" title="Editar">
                                <span class="glyphicon glyphicon-pencil"></span> editar
                            </a>

                            <a href="{{ route('manager.services.destroy', $service->id) }}" class="btn btn-default" data-delete="true" title="Excluir">
                                <span class="glyphicon glyphicon-trash"></span> excluir
                            </a>
                        </div><!-- .btn-group -->
                    </td>
                </tr>
            @endforeach
        </tbody>
    </table><!-- .table -->

    @if ($services->count() === 0)
        <h3 class="text-center">Nenhum registro encontrado.</h3>
    @endif

    {!! $services->appends(request()->except('page'))->render() !!}
@stop
